REM Name: findcommon.bat 
REM
REM Description: 
REM         finds the Common Component Directory for the MDB
REM         sets this as the value for the input variable
REM 
REM Syntax:
REM     variable_name potential_CCD_location
REM     
REM     variable_name = the enviroment variable that will hold the location of 
REM                     the CCD upon succesful completetion
REM     potential_CCD_location = location where to create the CCD if it does not
REM                              already exist
REM
REM Expects:
REM     TEMP (env), TMP (env) OR MDB_TARGET_DIR (script var) to already be defined
REM     PRECHECK=yes to surpress creation
REM     MDB_PATCH NEQ "" to surpress creation
REM
REM History:
REM  31-jan-2008  hopst01  created
REM  14-feb-2008  hopst01  updated to create Windows dir under MDB
REM                        use precheck and mdb_patch flags to skip registery creation
REM  19-feb-2008  hopst01  fail if tmp and temp don't exist and mdb_target unspecified
REM  27-feb-2008  hopst01  look for regedit in $windir if not on path. fail with 
REM                             appropriate message.
REM
REM  16-apr-2008  hopst01  17048271 - BETA: FINDCOMMON FAILS W/801
REM  17-apr-2008  hopst01  17048271 - BETA: FINDCOMMON FAILS W/801, update fix (17052666)
REM  05-dec-2008  hopst01  17704532 - R11.2 NM SQL DB UPDATE FAILS. For loops that use a 
REM                        a command to populate the for loop set should be replaced.
REM  12-jan-2008  hopst01  17704532 - R11.2 NM SQL DB UPDATE FAILS. Regedit output files created in 
REM                        Unicode format that is not compatible with for loop: use type instead.
REM

set MDBRC=801
set TCREATED=no
set MDB_COMMON_DIR=
set VAR_NAME=%~1
IF "%VAR_NAME%" EQU "" GOTO ARG_ERROR
IF ("%~2") NEQ ("") set MDB_COMMON_DIR_VAL=%~2
set TMPDIR=%TEMP%
IF ("%TMPDIR%") NEQ ("") IF EXIST "%TMPDIR%" GOTO TARGET_EXIST
set TMPDIR=%TMP%
IF ("%TMPDIR%") NEQ ("") IF EXIST "%TMPDIR%" GOTO TARGET_EXIST
set TMPDIR=%MDB_TARGET_DIR%
IF ("%TMPDIR%") NEQ ("") IF EXIST "%TMPDIR%" GOTO TARGET_EXIST
IF ("%MDB_TARGET_DIR%") EQU ("") GOTO TMPDIR_ERROR
IF EXIST "%MDB_TARGET_DIR%" GOTO TARGET_EXIST
mkdir "%MDB_TARGET_DIR%" > nul 2>&1
IF %ERRORLEVEL% EQU 0 GOTO TMPDIR_CREATED 
set MDBRC=802
set ERR_MESSAGE=Unable to create directory %MDB_TARGET_DIR%
GOTO EXIT
 
:TMPDIR_CREATED
set TCREATED=yes
GOTO TARGET_EXIST

:TMPDIR_ERROR
set MDBRC=804
set ERR_MESSAGE=Unable to locate system temp directory and MDB_TARGET_DIR unspecified
GOTO EXIT

:TARGET_EXIST

set REG_OUTPUT_FILE=%TMPDIR%\regout.txt
set REG_OUTPUT_FILE_COPY=%TMPDIR%\regout_copy.txt
set REG_IMPORT_FILE=%TMPDIR%\import.reg
set TMP_OUTPUT_FILE=%TMPDIR%\fndcommon.txt
set CA_SHARED_KEY=HKEY_LOCAL_MACHINE\Software\CA\Shared
set CA_SHARED_KEY_LONG=HKEY_LOCAL_MACHINE\Software\ComputerAssociates\Shared

rem
rem get proper regedit command, regedit doesn't fail for non-existent keys
rem 
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
SET REG_CMD=regedit.exe
rem force 0 command line errorcode
cd > nul 2>&1
%REG_CMD% /e "%REG_OUTPUT_FILE%" "noknownkey" > nul 2>&1
IF %ERRORLEVEL% EQU 0 GOTO DONE_GET_REG_CMD

IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
set REG_CMD="%windir%\regedit.exe"
cd > nul 2>&1
%REG_CMD% /e "%REG_OUTPUT_FILE%" "noknownkey" > nul 2>&1
IF %ERRORLEVEL% EQU 0 GOTO DONE_GET_REG_CMD

set MDBRC=805
set ERR_MESSAGE=Unable to find regedit.exe, please add it to the path
GOTO EXIT

:DONE_GET_REG_CMD

rem
rem is the MDB key already in registry
rem
:USE_SHORT_KEY
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
IF EXIST "%REG_OUTPUT_FILE_COPY%" DEL "%REG_OUTPUT_FILE_COPY%" > nul 2>&1
%REG_CMD% /e "%REG_OUTPUT_FILE%" "%CA_SHARED_KEY%\Mdb"
IF NOT EXIST "%REG_OUTPUT_FILE%" GOTO USE_LONG_KEY
type "%REG_OUTPUT_FILE%" > "%REG_OUTPUT_FILE_COPY%"
for /F "usebackq tokens=1,2* delims==" %%i IN ("%REG_OUTPUT_FILE_COPY%") DO IF("%%i") EQU (""InstallPath"") SET MDB_COMMON_DIR=%%j
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
SET T_MDB_COMMON_DIR="%MDB_COMMON_DIR%"
SET T_MDB_COMMON_DIR=%T_MDB_COMMON_DIR:"=%
IF ("%T_MDB_COMMON_DIR%") EQU ("") GOTO USE_LONG_KEY
GOTO CREATE_COMMON

:USE_LONG_KEY
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
IF EXIST "%REG_OUTPUT_FILE_COPY%" DEL "%REG_OUTPUT_FILE_COPY%" > nul 2>&1
%REG_CMD% /e "%REG_OUTPUT_FILE%" "%CA_SHARED_KEY_LONG%\Mdb"
IF NOT EXIST "%REG_OUTPUT_FILE%" GOTO CREATE_CCD_KEY
type "%REG_OUTPUT_FILE%" > "%REG_OUTPUT_FILE_COPY%" 
for /F "usebackq tokens=1,2* delims==" %%i IN ("%REG_OUTPUT_FILE_COPY%") DO IF("%%i") EQU (""InstallPath"") SET MDB_COMMON_DIR=%%j
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
SET T_MDB_COMMON_DIR="%MDB_COMMON_DIR%"
SET T_MDB_COMMON_DIR=%T_MDB_COMMON_DIR:"=%
IF ("%T_MDB_COMMON_DIR%") NEQ ("") GOTO CREATE_COMMON 

rem
rem Determine where to create the MDB CCD
rem if the short key is in the registry, use it
rem otherwise if the long key is in the registry, use it
rem else use the short key
rem
:CREATE_CCD_KEY
IF "%PRECHECK%" == "yes" GOTO PRECHECK_EXIT
IF "%MDB_PATCH%" NEQ "" GOTO PRECHECK_EXIT

set KEY=%CA_SHARED_KEY%\Mdb
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
%REG_CMD% /e "%REG_OUTPUT_FILE%" "%KEY%"
IF NOT EXIST "%REG_OUTPUT_FILE%" GOTO CHECK_SHORT_ROOT
GOTO SET_CCD_LOCATION

:CHECK_SHORT_ROOT
set KEY=%CA_SHARED_KEY_LONG%\Mdb
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
%REG_CMD% /e "%REG_OUTPUT_FILE%" "%KEY%"
IF NOT EXIST "%REG_OUTPUT_FILE%" GOTO USE_SHORT_ROOT_FAILED
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
GOTO SET_CCD_LOCATION

:USE_SHORT_ROOT_FAILED
set KEY=%CA_SHARED_KEY%\Mdb
GOTO SET_CCD_LOCATION

rem
rem determine where the CCD should be created
rem
:SET_CCD_LOCATION
IF ("%MDB_COMMON_DIR_VAL%") NEQ ("") GOTO IMPORT_KEY

:GET_PROGRAM_FILES
rem
rem regedit of large key causes delay, need to rely on env instead
rem
REM IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
REM IF EXIST "%TMP_OUTPUT_FILE%" DEL "%TMP_OUTPUT_FILE%" > nul 2>&1
REM %REG_CMD% /e "%REG_OUTPUT_FILE%" "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion"
REM find "ProgramFilesDir" "%REG_OUTPUT_FILE%" > "%TMP_OUTPUT_FILE%" 2>&1
REM IF NOT EXIST "%TMP_OUTPUT_FILE%" GOTO USE_ENV
REM for /F "usebackq tokens=1,2* delims==" %%i in (`find "ProgramFilesDir" "%TMP_OUTPUT_FILE%"`) do set MDB_COMMON_DIR_VAL=%%j
REM IF EXIST "%TMP_OUTPUT_FILE%" DEL "%TMP_OUTPUT_FILE%" > nul 2>&1
REM IF ("%MDB_COMMON_DIR_VAL%") EQU ("") GOTO USE_ENV
REM GOTO SET_CCD_LOCATION_CONT

:USE_ENV 
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
IF EXIST "%TMP_OUTPUT_FILE%" DEL "%TMP_OUTPUT_FILE%" > nul 2>&1
set MDB_COMMON_DIR_VAL=%PROGRAMFILES%
IF ("%MDB_COMMON_DIR_VAL%") EQU ("") GOTO SET_CCD_LOCATION_CONT 
IF ("%SYSTEMDRIVE%") EQU ("") (
    set MDB_COMMON_DIR_VAL=C:\Program Files
) ELSE (
    set MDB_COMMON_DIR_VAL=%SYSTEMDRIVE%\Program Files
)

:SET_CCD_LOCATION_CONT
set MDB_COMMON_DIR_VAL=%MDB_COMMON_DIR_VAL%\CA\SC\Mdb

:IMPORT_KEY
set MDB_COMMON_DIR=%MDB_COMMON_DIR_VAL%
IF EXIST "%REG_IMPORT_FILE%" DEL "%REG_IMPORT_FILE%" > nul 2>&1

set MDB_COMMON_DIR=%MDB_COMMON_DIR:\=\\%
echo REGEDIT4 >> "%REG_IMPORT_FILE%"
echo [%KEY%] >> "%REG_IMPORT_FILE%"
echo "InstallPath"="%MDB_COMMON_DIR%" >> "%REG_IMPORT_FILE%"
cd > nul 2>&1
%REG_CMD% /S "%REG_IMPORT_FILE%"
set MDBRC=%ERRORLEVEL%
IF EXIST "%REG_IMPORT_FILE%" DEL "%REG_IMPORT_FILE%" > nul 2>&1
IF %MDBRC% EQU 0 GOTO CREATE_COMMON
set ERR_MESSAGE=Unable to set the Commmon Component Directory for the MDB
set MDBRC=800
GOTO EXIT

:CREATE_COMMON
set MDB_COMMON_DIR=%MDB_COMMON_DIR:\\=\%
set MDB_COMMON_DIR=%MDB_COMMON_DIR:"=%
IF EXIST "%MDB_COMMON_DIR%" GOTO CREATE_OS_DIR 
mkdir "%MDB_COMMON_DIR%" > nul 2>&1
:CREATE_OS_DIR
IF EXIST "%MDB_COMMON_DIR%\Windows" GOTO DONE_EXIT
mkdir "%MDB_COMMON_DIR%\Windows" > nul 2>&1
GOTO DONE_EXIT

:PRECHECK_EXIT
SET MDBRC=0
GOTO EXIT

:DONE_EXIT 
IF EXIST "%MDB_COMMON_DIR%\Windows" (
    set MDBRC=0
) ELSE (
    IF "ERR_MESSAGE" EQU "" set ERR_MESSAGE=Unable to create the Common Component Directory for the MDB, "%MDB_COMMON_DIR%" 
)

:EXIT
IF EXIST "%REG_IMPORT_FILE%" DEL "%REG_IMPORT_FILE%" > nul 2>&1
IF ("%TCREATED%") EQU ("yes") rmdir "%MDB_TARGET_DIR%" /S /Q > nul 2>&1
set %VAR_NAME%=%MDB_COMMON_DIR%
EXIT /B %MDBRC%

:REG_EXPORT_ERROR
set MDBRC=801
set ERR_MESSAGE=Error reading MDB information from registry
GOTO DONE_EXIT

:ARG_ERROR
set MDBRC=803
set ERR_MESSAGE=findcommon must be called with an argument
GOTO EXIT