@echo off
@REM  copyright CA 2007
@REM 
@REM Purpose:
@REM    install the MDB schema where following scenarios are supported
@REM    fresh MDB install  
@REM    upgrading an existing MDB 1.0.4 to MDB 1.5
@REM
@REM
@REM    Platforms:
@REM        depending on the database type
@REM        MS SQl Server 2005
@Rem        Oracle 10g
@REM
@REM PRE-Regs
@REM        sqlplus must be found in the PATH 
@REM        osql must be in the PATH
@REM
@REM Usage 
@REM    just run command with the argument -?
@REM
@REM Return code
@REM        11001  command line error 
@REM        11099  validation of JRE failed
@REM        11098  java.exe not found
@REM        11097 database type not supported at this level of implementation
@REM        11010  Cannot find sqlplus. Check that Oracle has been installed and in the PATH
@REM        11011  Cannot find osql. Check that Oracle has been installed and in the PATH
@REM        11100 command error, ERRORLEVEL=%RC%, see logfile for details, applying AM synonyms returned an error 
@REM        11102 Error: MDB could not be installed see logfile for details
@REM        11103 failed to apply post_install on MSSQL
@REM        11104 failed to apply post_install on Oracle
@REM *************************************************************************
SETLOCAL

set PROG_COMMAND=%~f0 %*
set PROG=%~nx0
echo %date% %time% %PROG% started
set CLA=
@REM get current working directory
for /f "delims=," %%a in ('chdir') do set CURDIR=%%a

rem echo PROG_COMMAND=%PROG_COMMAND%
rem echo PROG_COMMAND=%PROG_COMMAND% >%TEMP%\mdb_inst.log 2>&1

REM
REM Set the default parameters
REM
set DBVENDOR=
set DBHOST=
set DBPORT=
set DBNAME=
set DBUSER=
set DBPASSWORD=
set MDBCOMPATIBILITY=no
set MDB_PRIVDIR=

set MDB_ADMIN_PSWD=
set ORA_DATA_TBLSPACE=na
set ORA_INDEX_TBLSPACE=na
set ORA_TBLSPACE_PATH=na

set ORA_SERVICE_NAME=
set ORA_DATA_SIZE=
set ORA_INDEX_SIZE=

@REM internal definitions
set Mdbdebug=

set JRE_DIR=..\jre\windows

set RC=0
set ERR_MESSAGE=Patch MDB error
set WORK_DIR=%CURDIR%


@REM MDB 1.5 definitions for MSSQL
set DBDRIVER_MSSQL=ITCM
set WORKSPACE_MSSQL=ITCM



@REM MDB 1.5 definitions for MSSQL
set DBDRIVER_ORACLE=ITCM
set WORKSPACE_ORACLE=ITCM

REM
REM Parse the command line parameters
REM

rem @echo on
rem set Mdbdebug=enabled
rem set CLA=%CLA%  -debug

:PARSE_ARGS

IF "%~1"==""   GOTO NO_MORE_ARGS
IF "%~1"=="-?" GOTO USAGE
IF "%~1"=="/?" GOTO USAGE
IF "%~1"=="/h" GOTO USAGE
IF "%~1"=="--help" GOTO USAGE

IF NOT "%~1"=="-debug" GOTO NEXT_ARG0
SHIFT
@echo on
set Mdbdebug=enabled
set CLA=%CLA%  -debug
GOTO PARSE_ARGS


:NEXT_ARG0
IF NOT "%~1"=="-DBVENDOR" GOTO NEXT_ARG1
SHIFT
set DBVENDOR=%~1
set CLA=%CLA% -DBVENDOR=%DBVENDOR%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG1
IF NOT "%~1"=="-DBHOST" GOTO NEXT_ARG2a
SHIFT
set DBHOST=%~1
set CLA=%CLA% -DBHOST=%DBHOST%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG2a
IF NOT "%~1"=="-DBINSTANCE" GOTO NEXT_ARG2b
SHIFT
set DBINSTANCE=%~1
set CLA=%CLA% -DBINSTANCE=%DBINSTANCE%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG2b
IF NOT "%~1"=="-DBPORT" GOTO NEXT_ARG3
SHIFT
set DBPORT=%~1
set CLA=%CLA% -DBPORT=%DBPORT%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG3
IF NOT "%~1"=="-DBNAME" GOTO NEXT_ARG4
SHIFT
set DBNAME=%~1
set CLA=%CLA% -DBNAME=%DBNAME%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG4
IF NOT "%~1"=="-DBUSER" GOTO NEXT_ARG5
SHIFT
set DBUSER=%~1
set CLA=%CLA% -DBUSER=%DBUSER%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG5
IF NOT "%~1"=="-DBPASSWORD" GOTO NEXT_ARG6
SHIFT
set DBPASSWORD=%~1
set CLA=%CLA% -DBPASSWORD=XXXX
IF "%DBPASSWORD%" == "" GOTO NO_DBPWD
GOTO PARSE_DBPWD

:NO_DBPWD
@REM check if username is set
echo no value given for argument -DBPASSWORD, check if user was given, might be trusted connection is used
IF "%DBUSER%" == "" GOTO END_PARSE_DBPWD
echo.%date% %time% Missing required argument: DBPASSWORD 
set ERR_MESSAGE=Missing required argument: DBPASSWORD
GOTO USAGE

:PARSE_DBPWD
rem Escape any reserved shell characters
set DBPASSWORD=%DBPASSWORD:^=^^%
set DBPASSWORD=%DBPASSWORD:<=^<%
set DBPASSWORD=%DBPASSWORD:>=^>%
set DBPASSWORD=%DBPASSWORD:|=^|%
set DBPASSWORD=%DBPASSWORD:&=^&%
set DBPASSWORD=%DBPASSWORD:(=^(%
set DBPASSWORD=%DBPASSWORD:)=^)%
set DBPASSWORD=%DBPASSWORD:"=\"%
:END_PARSE_DBPWD
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG6
IF NOT "%~1"=="-MDBCOMPATIBILITY" GOTO NEXT_ARG7a
SHIFT
set MDBCOMPATIBILITY="%~1"
set CLA=%CLA% -MDBCOMPATIBILITY=%MDBCOMPATIBILITY
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG7a
IF NOT "%~1"=="-JRE_DIR" GOTO NEXT_ARG7b
SHIFT
set JRE_DIR=%~1
set CLA=%CLA% -JRE_DIR=%JRE_DIR%
SHIFT
GOTO PARSE_ARGS



:NEXT_ARG7b
IF NOT "%~1"=="-MDB_ADMIN_PSWD" GOTO NEXT_ARG8
SHIFT
set MDB_ADMIN_PSWD=%~1
set CLA=%CLA% -MDB_ADMIN_PSWD=xxx
IF "%MDB_ADMIN_PSWD%" == "" GOTO NO_MDB_ADMIN_PSWD 
GOTO PARSE__MDB_ADMIN_PSWD

:NO_MDB_ADMIN_PSWD
echo %date% %time% Missing required argument: MDB_ADMIN_PSWD 
set ERR_MESSAGE=Missing required argument: MDB_ADMIN_PSWD
GOTO USAGE

:PARSE__MDB_ADMIN_PSWD
rem Escape any reserved shell characters
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:^=^^%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:<=^<%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:>=^>%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:|=^|%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:&=^&%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:(=^(%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:)=^)%
set MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD:"=\"%

SHIFT
GOTO PARSE_ARGS



:NEXT_ARG8
IF NOT "%~1"=="-ORA_TBLSPACE_PATH" GOTO NEXT_ARG9
SHIFT
set ORA_TBLSPACE_PATH=%~1
set CLA=%CLA% -ORA_TBLSPACE_PATH=%ORA_TBLSPACE_PATH%
SHIFT
GOTO PARSE_ARGS


:NEXT_ARG9
IF NOT "%~1"=="-ORA_INDEX_TBLSPACE" GOTO NEXT_ARG10
SHIFT
set ORA_INDEX_TBLSPACE=%~1
set CLA=%CLA% -ORA_INDEX_TBLSPACE=%ORC_INDEX_TBLSPACE%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG10
IF NOT "%~1"=="-ORA_DATA_TBLSPACE" GOTO NEXT_ARG11
SHIFT
set ORA_DATA_TBLSPACE=%~1
set CLA=%CLA% -ORA_DATA_TBLSPACE=%ORA_DATA_TBLSPACE%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG11
IF NOT "%~1"=="-MDB_PRIVDIR" GOTO NEXT_ARG12
SHIFT
set MDB_PRIVDIR=%~1
set CLA=%CLA% -MDB_PRIVDIR="%MDB_PRIVDIR%"
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG12
IF NOT "%~1"=="-ORA_SERVICE_NAME" GOTO NEXT_ARG13
SHIFT
set ORA_SERVICE_NAME=%~1
set CLA=%CLA% -ORA_SERVICE_NAME=%ORA_SERVICE_NAME%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG13
IF NOT "%~1"=="-ORA_DATA_SIZE" GOTO NEXT_ARG14
SHIFT
set ORA_DATA_SIZE=%~1
set CLA=%CLA% -ORA_DATA_SIZE=%ORA_DATA_SIZE%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG14
IF NOT "%~1"=="-ORA_INDEX_SIZE" GOTO NEXT_ARG15
SHIFT
set ORA_INDEX_SIZE=%~1
set CLA=%CLA% -ORA_INDEX_SIZE=%ORA_INDEX_SIZE%
SHIFT
GOTO PARSE_ARGS

:NEXT_ARG15

:INVALID_ARG
echo %date% %time% Usage: Invalid argument "%~1"
set ERR_MESSAGE=Invalid %PROG% argument "%~1"
GOTO USAGE

:NO_MORE_ARGS

rem
rem check required arguments
rem

IF (%DBVENDOR%) NEQ () GOTO REQ_ARG_HOST
echo %date% %time% Missing required argument: DBVENDOR 
set ERR_MESSAGE=Missing required argument: DBVENDOR
GOTO USAGE

:REQ_ARG_HOST
IF (%DBHOST%) NEQ () GOTO REQ_ARG_PORT
echo %date% %time% Missing required argument: DBHOST 
set ERR_MESSAGE=Missing required argument: DBHOST
GOTO USAGE

:REQ_ARG_PORT
IF (%DBPORT%) NEQ () GOTO REQ_ARG_DBNAME
echo %date% %time% Missing required argument: DBPORT 
set ERR_MESSAGE=Missing required argument: DBPORT
GOTO USAGE

:REQ_ARG_DBNAME
IF (%DBNAME%) NEQ () GOTO REQ_ARG_DBUSER
echo %date% %time% Missing required argument: DBNAME 
set ERR_MESSAGE=Missing required argument: DBNAME
GOTO USAGE


:REQ_ARG_DBUSER
IF (%DBUSER%) NEQ () GOTO REQ_ARGDBPWD
echo %date% %time% Missing argument: DBUSER, assume trusted connection / OS Authentication is used


:REQ_ARGDBPWD
IF ("%DBPASSWORD%") NEQ ("") GOTO REQ_ARG_COMPAT
echo %date% %time% Missing required argument: DBPASSWORD, assume trusted connection / OS Authentication is used
set ERR_MESSAGE=Missing required argument: DBPASSWORD



:REQ_ARG_COMPAT
IF (%MDBCOMPATIBILITY%) NEQ () GOTO REQ_ARG_DEFEND
echo %date% %time% Missing required argument: MDBCOMPATIBILITY 
set ERR_MESSAGE=Missing required argument: MDBCOMPATIBILITY
GOTO USAGE


:REQ_ARG_DEFEND
@REM check the additional argument onyl if oracle

IF (%DBVENDOR%) == (oracle) goto CHECK_ORA_ARGS
goto END_ORA_ARGS 

:CHECK_ORA_ARGS
    IF "%MDB_ADMIN_PSWD%" NEQ "" GOTO REQ_ARG_DATTBLS
    echo %date% %time% Missing required argument: MDB_ADMIN_PSWD 
    set ERR_MESSAGE=Missing required argument: MDB_ADMIN_PSWD
    GOTO USAGE
    
:REQ_ARG_DATTBLS
    IF "%ORA_TBLSPACE_PATH%" NEQ "" GOTO REQ_ARG_IDXTBLS
    echo %date% %time% Missing required argument: ORA_TBLSPACE_PATH 
    set ERR_MESSAGE=Missing required argument: ORA_TBLSPACE_PATH
    GOTO USAGE
    
:REQ_ARG_IDXTBLS
    IF "%ORA_INDEX_TBLSPACE%" NEQ "" GOTO REQ_ARG_DATATBLS
    echo %date% %time% Missing required argument: REQ_ARG_DATATBLS 
    set ERR_MESSAGE=Missing required argument: ORA_INDEX_TBLSPACE
    GOTO USAGE
    
:REQ_ARG_DATATBLS
    IF "%ORA_DATA_TBLSPACE%" NEQ "" GOTO REQ_ARG_ORASERVICE
    echo %date% %time% Missing required argument: ORA_DATA_TBLSPACE 
    set ERR_MESSAGE=Missing required argument: ORA_DATA_TBLSPACE
    GOTO USAGE

:REQ_ARG_ORASERVICE
    IF "%ORA_DATA_TBLSPACE%" NEQ "" GOTO REQ_ARG_DATASIZE
    echo %date% %time% Missing required argument: ORA_SERVICE_NAME 
    set ERR_MESSAGE=Missing required argument: ORA_SERVICE_NAME
    GOTO USAGE

:REQ_ARG_DATASIZE
    IF "%ORA_DATA_SIZE%" NEQ "" GOTO REQ_ARG_IDXSIZE
    echo %date% %time% Missing required argument: ORA_DATA_SIZE 
    set ERR_MESSAGE=Missing required argument: ORA_DATA_SIZE
    GOTO USAGE
    
:REQ_ARG_IDXSIZE
    IF "%ORA_INDEX_SIZE%" NEQ "" GOTO REQ_ARG_ORAEND
    echo %date% %time% Missing required argument: ORA_INDEX_SIZE 
    set ERR_MESSAGE=Missing required argument: ORA_INDEX_SIZE
    GOTO USAGE
    
:REQ_ARG_ORAEND

) 
:END_ORA_ARGS
:DO_INSTALL

@REM
@REM basic JAVA environment validation
@REM


IF EXIST "%JRE_DIR%"  GOTO JRE_DIR_EXIST
set ERR_MESSAGE=Invalid JRE_DIR directory: "%JRE_DIR%" does not exist
set RC=11098
GOTO DONE_EXIT

:JRE_DIR_EXIST
IF EXIST "%JRE_DIR%\bin\java.exe" GOTO JRE_JAVA_EXIST
set ERR_MESSAGE=Invalid JRE_DIR directory: JRE file "%JRE_DIR%\bin\java.exe" does not exist
set RC=11099
GOTO DONE_EXIT



:JRE_JAVA_EXIST
"%JRE_DIR%\bin\java.exe" -version 

@Rem check MDB Compatibility mode
IF %MDBCOMPATIBILITY%=="yes" GOTO SET_MDBCOMPATMODE
set MDBCOMPATMODE=
echo %date% %time% %PROG% installing MDB where compatibility mode is disabled
goto :CHECK_PRIVDIR

:SET_MDBCOMPATMODE
set MDBCOMPATMODE=-COMPAT104
echo %date% %time% %PROG% installing MDB where compatibility mode is enabled, using flag %MDBCOMPATMODE%
goto :CHECK_PRIVDIR




:CHECK_PRIVDIR
@Rem check MDB private flder set?
IF "%MDB_PRIVDIR%"=="" GOTO NOTSET_PRIVDIR
set MDB_PRIVDIR=-MDB_PRIVATE_DIR="%MDB_PRIVDIR%"
echo %date% %time% %PROG% installing MDB where privtae folder is set to [%MDB_PRIVDIR%] 
goto :CHECK_PRIVDIR_END

:NOTSET_PRIVDIR
set MDB_PRIVDIR=
echo %date% %time% %PROG% installing MDB where private folder is not set, going with the default settings 

:CHECK_PRIVDIR_END


:INSTALL
REM
REM Set the log file
REM

echo %date% %time% %PROG% mdb log file for MDB install in %LOGFILE%



if (%DBVENDOR%) == (mssql) goto INSTALL_MSSQL_SCHEMA
if (%DBVENDOR%) == (oracle) goto INSTALL_ORACLE_SCHEMA
set RC=11097
set ERR_MESSAGE=Error: database type not supported at this level of implementation
GOTO DONE_EXIT


:INSTALL_MSSQL_SCHEMA
@REM *******************************************************************
@REM
@REM install mdb on SQL Server
@REM
@REM *******************************************************************
echo %date% %time% installing MDB on MsSql...


@REM
@REM check if osql is available
@REM ********************************
call osql -? > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
	set SQL_CMD=osql
	GOTO OSQL_FOUND
)
set RC=11011
set ERR_MESSAGE=Cannot find osql. Check that MSSQL client has been installed and in the PATH
GOTO DONE_EXIT
:OSQL_FOUND


@REM install MDB Schema
@REM ********************************
@REM chdir /D "mssql"
set MDB_SOURCE_DIR=%WORK_DIR%\mdb_install
set MDB_TARGET_DIR=%WORK_DIR%\mdb_install

if (%DBINSTANCE%) NEQ () set DBHOST=%DBHOST%\%DBINSTANCE%
set AUTHENTICATION=
if (%DBUSER%) NEQ () set AUTHENTICATION=-DBUSER=%DBUSER% -DBPASSWORD="%DBPASSWORD%" 

@REM run pre install script
@echo starting pre install script ...

if (%DBUSER%) NEQ () (
	@echo call %SQL_CMD%  -S "%DBHOST%,%DBPORT%" -d %DBNAME% -U %DBUSER% -P "****"  -i .\mdb_install\mssql\pre_install.sql
	call %SQL_CMD%  -S "%DBHOST%,%DBPORT%" -d %DBNAME%  -U %DBUSER% -P "%DBPASSWORD%"  -i .\mdb_install\mssql\pre_install.sql
) else (
	@echo call %SQL_CMD%  -S "%DBHOST%,%DBPORT%" -d %DBNAME% -E -i .\mdb_install\mssql\pre_install.sql
	call %SQL_CMD%  -S "%DBHOST%,%DBPORT%" -d %DBNAME% -E -i .\mdb_install\mssql\pre_install.sql
) 
@echo pre install script terminated with ERRORLEVEL=%ERRORLEVEL%

@REM run schema installation
@echo run schema installation
call .\mdb_install\setupmdb.bat -DBVENDOR=%DBVENDOR%  -DBNAME=%DBNAME% -DBHOST=%DBHOST% -DBPORT=%DBPORT% %AUTHENTICATION% -DBDRIVER="%DBDRIVER_MSSQL%" -WORKSPACE="%WORKSPACE_MSSQL%" -JRE_DIR="%JRE_DIR%" -MDB_SOURCE_DIR="%MDB_SOURCE_DIR%" -MDB_TARGET_DIR="%MDB_TARGET_DIR%" -MDB_EXIT_SCRIPT=no  %MDBCOMPATMODE% %MDB_PRIVDIR% 
IF %ERRORLEVEL% EQU 0 GOTO MDB_INSTALLED
:MDB_NOT_INSTALLED
set RC=%ERRORLEVEL%
set ERR_MESSAGE=Error: MDB could not be installed see logfile for details
GOTO DONE_EXIT
:MDB_INSTALLED
GOTO DONE_EXIT


:INSTALL_ORACLE_SCHEMA
@REM *******************************************************************
@REM
@REM install mdb on Oracle
@REM
@REM *******************************************************************
echo %date% %time% installing MDB on oracle...



@REM
@REM check if Oracle is available
@REM ********************************
sqlplus -V > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
    set SQL_CMD=sqlplus
    GOTO SQLPLUS_FOUND
)
set RC=11010
set ERR_MESSAGE=Cannot find sqlplus. Check that Oracle has been installed and in the PATH
GOTO DONE_EXIT
:SQLPLUS_FOUND


@REM install MDB Schema
@REM ********************************
@REM chdir /D "oracle"
set MDB_SOURCE_DIR=%WORK_DIR%\mdb_install
set MDB_TARGET_DIR=%WORK_DIR%\mdb_install

call .\mdb_install\setupmdb.bat -DBVENDOR=%DBVENDOR%  -DBNAME=%DBNAME% -DBHOST=%DBHOST% -DBPORT=%DBPORT% -DBUSER=%DBUSER% -DBPASSWORD=%DBPASSWORD% -DBDRIVER=%DBDRIVER_ORACLE% -WORKSPACE=%WORKSPACE_ORACLE%   -ORA_DATA_SIZE=%ORA_DATA_SIZE% -ORA_INDEX_SIZE=%ORA_INDEX_SIZE% -ORA_DATA_TBLSPACE=%ORA_DATA_TBLSPACE% -ORA_INDEX_TBLSPACE=%ORA_INDEX_TBLSPACE% -ORA_TBLSPACE_PATH="%ORA_TBLSPACE_PATH%" -MDB_ADMIN_PSWD=%MDB_ADMIN_PSWD% -JRE_DIR="%JRE_DIR%" -MDB_SOURCE_DIR="%MDB_SOURCE_DIR%" -MDB_TARGET_DIR="%MDB_TARGET_DIR%" -MDB_EXIT_SCRIPT=no %MDBCOMPATMODE%  %MDB_PRIVDIR%  -ORA_SERVICE_NAME=%ORA_SERVICE_NAME%
IF %ERRORLEVEL% EQU 0 GOTO MDB_INSTALLED
:MDB_NOT_INSTALLED
set RC=%ERRORLEVEL%
set ERR_MESSAGE=Error: MDB could not be installed see logfile for details
GOTO DONE_EXIT
:MDB_INSTALLED
GOTO DONE_EXIT


:USAGE
echo.
echo.  Usage %PROG% options
echo.
echo    Options:
echo. 
echo.       -DBVENDOR         { mssql ^| oracle }
echo.       -DBHOST           ^<database server name^>
echo.       -DBINstance       ^<instance name, in case of oracle pleae use empty string like ""^>
echo.                         ^<also in case of default instance on MS SQL, please use ""^>
echo        -DBPORT           ^<port number of the database instance 
echo                          i.e.1433 on mssql, 1521 on Oracle ^>
echo.       -DBNAME           ^<name of the database i.e.mdb ^>
echo        -DBUSER           ^<valid database user with
echo                           i.e sa on MSSQL and sys on Oracle ^>
echo        -DBPASSWORD       ^<password of the DBUSER^>
echo        [-MDBCOMPATIBILITY { yes ^| no } default value is 'no']
echo        [-JRE_DIR          ^<directory where JRE is located ^> ]
echo        [-MDB_PRIVDIR      ^<directory where MDB private is located ^> ]
echo.
echo  on Oracle the following additional arguments are needed
echo        -MDB_ADMIN_PSWD      ^<password of mdbadmin^>
echo        -ORA_TBLSPACE_PATH   ^<absolute path to tablespace of mdb^>
echo.       -ORA_DATA_TBLSPACE   ^<data tablespace name^>
echo        -ORA_INDEX_TBLSPACE  ^<index tablespace name^>
echo        -ORA_SERVICE_NAME  ^<service name^>
echo        -ORA_DATA_SIZE  ^<MDB data size^>
echo        -ORA_INDEX_SIZE  ^<MDB index size^>
echo       [-debug]              ^<echo output^>
echo. 
echo. 
echo. 
echo. Ingres example:
echo. %PROG% -DBVENDOR=ingres -DBUSER=mdbadmin -DBPASSWORD=mdbadmin
echo. 
echo. SQLServer example:
echo. %PROG% -DBVENDOR=mssql  -DBUSER=sa -DBPASSWORD=sa
echo. 
echo. Oracle example:
echo. %PROG% -DBVENDOR=oracle -DBNAME=ORCL -DBUSER=sys -DBPASSWORD=sys
echo.            -MDB_ADMIN_PSWD=mdbadmin
echo.           -ORA_TBLSPACE_PATH=d:\oracle\product\10.2.0\oradata\orcl
echo.           -ORA_SERVICE_NAME=ORCL
echo.            
echo. 
echo Script was called with the following arguments:
echo %CLA%
echo.
echo %ERR_MESSAGE%

set RC=11001
echo EXIT %RC%
EXIT %RC%


:DONE_EXIT
echo %date% %time% 
echo %date% %time% Return code %RC%, %ERR_MESSAGE%

@REM Setting directory back to "%CURDIR%" 
chdir /D "%CURDIR%"

echo EXIT %RC%
EXIT  %RC%
