SET LOCK_TIMEOUT 300000
GO
SET DEADLOCK_PRIORITY LOW
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION 
GO

/****************************************************************************************/
/*                                                                                      */
/* Star 16505478 CMDB new vis_ and ci_ tables */
/*                                                                                      */
/****************************************************************************************/

/* lock objects...  */
 
/* Start of lines added to convert to online lock */
 
 
Select top 1 1 from mdb_patch with (tablockx)
GO
 
/* Start of locks for dependent tables */
 
Select top 1 1 from mdb_service_pack with (tablockx)
GO
 
Select top 1 1 from mdb with (tablockx)
GO
 
Select top 1 1 from mdb_checkpoint with (tablockx)
GO
 
/* End of lines added to convert to online lock */

/* 16584925 MDB auto-build CRPatch */
Select top 1 1 from usp_owned_resource with (tablockx)
GO
 
Select top 1 1 from ci_rel_type with (tablockx)
GO
 
/* End of lines added to convert to online lock */


/****** QC 525: Clarity content ******/

CREATE TABLE ci_investment_other
(
     id int NOT NULL  ,
     persid nvarchar (30) NULL  ,
     del int NOT NULL  ,
     last_mod_dt int NULL  ,
     last_mod_by binary(16) NULL  ,
     ext_asset binary(16) NOT NULL  ,
     type nvarchar (30) NULL  ,
     risk nvarchar(30) NULL  ,
     manager nvarchar(2000) NULL  ,
     alignment int NULL  ,
     active int NULL  ,
     stage nvarchar(2000) NULL  ,
     goal nvarchar(2000) NULL  ,
     investment_priority int NULL  ,
     investment_status nvarchar (240) NULL  ,
     status_indicator nvarchar (20) NULL  ,
     status_comment nvarchar(2000) NULL  ,
     charge_code nvarchar (50) NULL  ,
     start_date int NULL  ,
     finish_date int NULL  ,
     progress nvarchar (50) NULL  ,
     total_cost nvarchar (30) NULL  ,
     total_effort nvarchar (30) NULL  ,
     currency nvarchar (3) NULL,
PRIMARY KEY NONCLUSTERED 
(
	id ASC
) ON [PRIMARY]
) ON [PRIMARY] 
GO

GRANT SELECT , UPDATE , INSERT , DELETE ON dbo.ci_investment_other TO service_desk_admin_group
GO

GRANT SELECT ON dbo.ci_investment_other TO service_desk_ro_group
GO

CREATE UNIQUE CLUSTERED INDEX ci_investment_other_X0 ON ci_investment_other (ext_asset) 
GO


CREATE TABLE dbo.ci_investment_idea
(
     id int NOT NULL  ,
     persid nvarchar (30) NULL  ,
     del int NOT NULL  ,
     last_mod_dt int NULL  ,
     last_mod_by binary(16) NULL  ,
     ext_asset binary(16) NOT NULL  ,
     target_manager nvarchar(2000) NULL  ,
     business_unit nvarchar (90) NULL  ,
     active int NULL  ,
     est_start_date int NULL  ,
     est_finish_date int NULL  ,
     existing_initiative_impact nvarchar(2000) NULL  ,
     dependencies nvarchar(2000) NULL  ,
     risks nvarchar(2000) NULL  ,
     owner nvarchar(2000) NULL,
     idea_priority nvarchar(30) NULL  ,
     subject nvarchar(300) NULL  ,
     general_notes nvarchar(2000) NULL  ,
PRIMARY KEY NONCLUSTERED 
(
	id ASC
) ON [PRIMARY]
) ON [PRIMARY] 
GO

GRANT SELECT , UPDATE , INSERT , DELETE ON dbo.ci_investment_idea TO service_desk_admin_group
GO

GRANT SELECT ON dbo.ci_investment_idea TO service_desk_ro_group
GO

CREATE UNIQUE CLUSTERED INDEX ci_investment_idea_X0 ON dbo.ci_investment_idea (ext_asset) 
GO

CREATE TABLE dbo.ci_investment_project
(
     id int NOT NULL  ,
     persid nvarchar (30) NULL  ,
     del int NOT NULL  ,
     last_mod_dt int NULL  ,
     last_mod_by binary(16) NULL  ,
     ext_asset binary(16) NOT NULL  ,
     risk nvarchar(30) NULL  ,
     manager nvarchar(2000) NULL  ,
     alignment int NULL  ,
     active int NULL  ,
     stage nvarchar(2000) NULL  ,
     goal nvarchar(2000) NULL  ,
     project_priority int NULL  ,
     project_status nvarchar (240) NULL  ,
     status_indicator nvarchar (20) NULL  ,
     status_comment nvarchar(2000) NULL  ,
     charge_code nvarchar (96) NULL  ,
     start_date int NULL  ,
     finish_date int NULL  ,
     progress nvarchar (50) NULL  ,
     total_cost nvarchar (30) NULL  ,
     total_effort nvarchar (30) NULL  ,
     currency nvarchar (3) NULL,
PRIMARY KEY NONCLUSTERED 
(
	id ASC
) ON [PRIMARY]
) ON [PRIMARY] 
GO
GRANT SELECT , UPDATE , INSERT , DELETE ON dbo.ci_investment_project TO service_desk_admin_group
GO

GRANT SELECT ON dbo.ci_investment_project TO service_desk_ro_group
GO

CREATE UNIQUE CLUSTERED INDEX ci_investment_project_X0 ON ci_investment_project (ext_asset) 
GO

/****** QC 433: Baseline CI support ******/

ALTER TABLE usp_owned_resource ADD baseline_uuid binary(16) NULL
GO

/****** QC 400: CMDBVisualizer : table stores the metadata of a filter ******/

CREATE TABLE vis_object_store_master (
	id int NOT NULL ,
	object_name nvarchar(100) NOT NULL ,
	creation_user binary(16) NULL ,
	creation_date int NULL ,
	last_update_date int NULL ,
	last_update_user binary(16) NULL ,
	description nvarchar(255) NULL,
	object_sub_type smallint NULL,
	object_type smallint NOT NULL,
	inactive int NOT NULL ,
	derived_from_type int NULL ,
PRIMARY KEY NONCLUSTERED
(
	id ASC
) ON [PRIMARY]
) ON [PRIMARY] 
GO

GRANT SELECT , UPDATE , INSERT , DELETE ON vis_object_store_master TO service_desk_admin_group
GO

GRANT SELECT ON vis_object_store_master TO service_desk_ro_group
GO

/****** QC 400: CMDBVisualizer : table stores the filter parameters in key value pair. ******/


CREATE TABLE vis_object_store_criteria (
	id int NOT NULL,
	object_id int NOT NULL ,
	object_criteria_name varchar(32) NOT NULL,
	object_criteria_value nvarchar(2000) NULL,
	last_update_date int NULL,
	inactive int NOT NULL,
PRIMARY KEY NONCLUSTERED
(
	id ASC
) ON [PRIMARY]
) ON [PRIMARY] 
GO

ALTER TABLE vis_object_store_criteria WITH CHECK ADD CONSTRAINT vis_object_store_criteria_fk FOREIGN KEY(object_id)
REFERENCES vis_object_store_master (id)
GO

GRANT SELECT , UPDATE , INSERT , DELETE ON vis_object_store_criteria TO service_desk_admin_group
GO

GRANT SELECT ON vis_object_store_criteria TO service_desk_ro_group
GO

/****** QC 400: CMDBVisualizer : table is used to save the graph. ******/


CREATE TABLE vis_graph_metadata (
	id int NOT NULL ,
	focus_ci_list varchar(1024) NOT NULL ,
	graph_level smallint NOT NULL,
	layout smallint NOT NULL ,
	filter_id int NULL ,
	hidden_ci_list varchar(2048) NULL ,
	inactive int NOT NULL ,
	graph_name nvarchar(100) UNIQUE NOT NULL ,
	creation_user binary(16) NULL ,
	creation_date int NULL ,
	last_update_user binary(16) NULL ,
	last_update_date int NULL ,
PRIMARY KEY NONCLUSTERED
(
	id ASC
) ON [PRIMARY]
) ON [PRIMARY] 
GO

ALTER TABLE vis_graph_metadata WITH CHECK ADD CONSTRAINT vis_graph_metadata_fk FOREIGN KEY(filter_id)
REFERENCES vis_object_store_master (id)
GO

GRANT SELECT , UPDATE , INSERT , DELETE ON vis_graph_metadata TO service_desk_admin_group
GO

GRANT SELECT ON vis_graph_metadata TO service_desk_ro_group
GO

/****** QC 400: CMDBVisualizer : table stores the configuration parameters in key value pair. ******/


CREATE TABLE vis_configuration (
	id int NOT NULL ,
	visconfig_criteria1 varchar(100) UNIQUE NOT NULL,
	visconfig_criteria2 varchar(100) NULL,
	visconfig_criteria3 varchar(100) NULL,
	visconfig_criteria_value varchar(100) NULL,
	creation_user binary(16) NULL ,
	creation_date int NULL ,
	last_update_user binary(16) NULL ,
	last_update_date int NULL ,
	inactive int NOT NULL ,
PRIMARY KEY NONCLUSTERED
(
	id ASC
) ON [PRIMARY]
) ON [PRIMARY] 
GO

GRANT SELECT , UPDATE , INSERT , DELETE ON vis_configuration TO service_desk_admin_group
GO

GRANT SELECT ON vis_configuration TO service_desk_ro_group
GO


/****** QC 400: CMDBVisualizer : table is modified for the color combination to be applied on a relationship. ******/


ALTER TABLE ci_rel_type
ADD view_style VARCHAR(15) 
GO




/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                               	*/
/*                                                                                      */
/****************************************************************************************/
insert into mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 values ( 16505478, getdate(), 1, 4, 'Star 16505478 CMDB new vis_ and ci_ tables' )
GO

COMMIT TRANSACTION 
GO

