SET LOCK_TIMEOUT 300000
GO
SET DEADLOCK_PRIORITY LOW
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION 
GO

/****************************************************************************************/
/*                                                                                      */
/* Star 16507685 BABLD: changes for SOA							*/
/*                                                                                      */
/****************************************************************************************/

/* lock objects...  */
 
/* Start of lines added to convert to online lock */
 
 
Select top 1 1 from mdb_patch with (tablockx)
GO
 
/* Start of locks for dependent tables */
 
Select top 1 1 from mdb_service_pack with (tablockx)
GO
 
Select top 1 1 from mdb with (tablockx)
GO
 
Select top 1 1 from mdb_checkpoint with (tablockx)
GO
 
Select top 1 1 from backup_server with (tablockx)
GO
 
Select top 1 1 from backup_job with (tablockx)
GO
 
Select top 1 1 from backup_server_config with (tablockx)
GO
 
Select top 1 1 from backup_user with (tablockx)
GO
 
Select top 1 1 from backup_agent_config with (tablockx)
GO
 
Select top 1 1 from backup_set with (tablockx)
GO
 
Select top 1 1 from backup_policy with (tablockx)
GO
 
Select top 1 1 from backup_email_def with (tablockx)
GO
 
Select top 1 1 from backup_msg_log with (tablockx)
GO
 
/* End of lines added to convert to online lock */


/* ================================================================ */
/* Change existing table backup_server							    */
/* ================================================================ */

alter table backup_server add last_notify_time integer null;
alter table backup_server add total_registered_user integer null;
alter table backup_server add last_run_date integer null;

go



/* ================================================================ */
/* Change existing table backup_job							    */
/* ================================================================ */


drop index [dbo].[backup_job].[xif1backup_job]
GO

alter table backup_job alter column server_id binary(16) Null
go 

CREATE  INDEX [xif1backup_job] ON [dbo].[backup_job]([server_id]) ON [PRIMARY]
GO


/*
 **************************************************************************
 procedure to set last sequential number for jobs in backup_manager table
*/

ALTER  procedure  backup_p_job_seq_number
	@_manager_id binary(16) 
as 
begin
	declare @_last_seq_number integer;
	declare @_max_seq_number integer;
	
	select @_last_seq_number = 
		(select bmgr.job_last_seq_number
			 from backup_manager bmgr 
			 where (bmgr.manager_id = @_manager_id));

	select @_max_seq_number = 
		(select bmgr.job_max_seq_number
			 from backup_manager bmgr 
			 where (bmgr.manager_id = @_manager_id));
 
	if ((@_max_seq_number = 0) or 
		(@_last_seq_number < @_max_seq_number)) 
		begin 
			set @_last_seq_number = @_last_seq_number + 1;
		end;	
	else 
		begin
			set @_last_seq_number = 0;
		end;	
	  
	update backup_manager
  		set job_last_seq_number = @_last_seq_number
  		where manager_id = @_manager_id;
end;

go



/*
 *********************************************
 trigger for inserting backup_job entry
*/

alter trigger backup_r_insert_job
			on backup_job
            after insert
	as
    begin
		declare @_domain_uuid binary(16);
		select  @_domain_uuid = 
			(select set_val_uuid from ca_settings where (set_id=1));

		declare @_manager_id binary(16);
		select	@_manager_id = (select manager_id from backup_manager where (domain_uuid = @_domain_uuid));

		execute backup_p_job_seq_number @_manager_id;
	end;

GO



/* ================================================================ */
/* Change existing table backup_server_config					    */
/* ================================================================ */

alter table backup_server_config add disk_notify_condition integer null;
alter table backup_server_config add disk_notify_method integer null;
alter table backup_server_config add disk_notify_threshold_size integer null;
alter table backup_server_config add disk_notify_threshold_percent integer null;
alter table backup_server_config add notify_repeat_period integer null;
alter table backup_server_config add data_encryption integer null;
alter table backup_server_config add sec_connection_port_min integer null;
alter table backup_server_config add sec_connection_port_max integer null;

go


/* ================================================================ */
/* Change existing table backup_user							    */
/* ================================================================ */

alter table backup_user add last_notify_time integer null;
alter table backup_user add user_status integer null;
alter table backup_user add service_isp_id binary(16) null;

CREATE INDEX xif14backup_user ON backup_user
(
       service_isp_id               ASC
);

alter table backup_user add staging_server_id binary(16) null; 

CREATE INDEX xif15backup_user ON backup_user
(
       staging_server_id               ASC
);

alter table backup_user add email_address nvarchar(255) null;
alter table backup_user add random_password char(1) null;

go


/* ================================================================ */
/* Change existing table backup_agent_config					    */
/* ================================================================ */

alter table backup_agent_config add service_isp_id binary(16) null;

CREATE INDEX xif3backup_agent_config ON backup_agent_config
(
       service_isp_id               ASC
);

alter table backup_agent_config add quota_notify_condition integer null;
alter table backup_agent_config add quota_notify_method integer null;
alter table backup_agent_config add quota_notify_threshold_size integer null;
alter table backup_agent_config add quota_notify_threshold_percent integer null;
alter table backup_agent_config add notify_repeat_period integer null;
alter table backup_agent_config add agent_behavior integer null;
alter table backup_agent_config add secure_connection integer null;

go


/* ================================================================ */
/* Change existing table backup_set							    */
/* ================================================================ */

alter table backup_set add service_isp_id binary(16) null;

CREATE INDEX xif1backup_set ON backup_set
(
       service_isp_id               ASC
);

go


/* ================================================================ */
/* Change existing table backup_policy							    */
/* ================================================================ */

alter table backup_policy add service_isp_id binary(16) null;

CREATE INDEX xif5backup_policy ON backup_policy
(
       service_isp_id               ASC
);

go


/* ================================================================ */
/* Change existing table backup_email_def						    */
/* ================================================================ */

alter table backup_email_def add type char(1) null;
alter table backup_email_def add status integer null;
alter table backup_email_def add receiver_id binary(16) null;

CREATE INDEX xif1backup_email_def ON backup_email_def
(
       receiver_id               ASC
);

alter table backup_email_def add receiver_type char(1) null; 

go


/* ================================================================ */
/* Change existing table backup_msg_log  						    */
/* ================================================================ */

alter table backup_msg_log add service_isp_id binary(16) null;
alter table backup_msg_log add service_admin_id binary(16) null;

CREATE INDEX xif4backup_msg_log ON backup_msg_log
(
       service_isp_id               ASC
);

CREATE INDEX xif5backup_msg_log ON backup_msg_log
(
       service_admin_id             ASC
);

go


/* ================================================================ */
/* Change existing table backup_job 						    */
/* ================================================================ */

alter table backup_job add service_isp_id binary(16) null;
alter table backup_job add service_admin_id binary(16) null;

CREATE INDEX xif4backup_job ON backup_job
(
       service_isp_id               ASC
);

CREATE INDEX xif5backup_job ON backup_job
(
       service_admin_id             ASC
);

go


/* ================================================================ */
/* Create new table backup_service_msp							    */
/* ================================================================ */

CREATE TABLE backup_service_msp (
		service_msp_id				binary(16) not null,
		manager_id					binary(16) not null,
		name						nvarchar(255) null,
		description					nvarchar(255) collate !!sensitive null,
		logo_branding				nvarchar(255) collate !!sensitive null,	
		logo_graphical_reference	nvarchar(255) collate !!sensitive null,
	    registered_companies		integer null,
		group_quota					integer null,
		member_quota				integer null,
		quota_notify_threshold_percent 		integer null,
		quota_notify_method			integer null,
		contact_info				nvarchar(1024) collate !!sensitive null,	
		creation_user				nvarchar(255) collate !!sensitive null, 
		creation_date				integer null ,
		last_update_user			nvarchar(255) collate !!sensitive null,
		last_update_date			integer null,
		version_number				integer null,
		);

ALTER TABLE backup_service_msp ADD 
CONSTRAINT XPKbackup_service_msp PRIMARY KEY  CLUSTERED 
	(
		service_msp_id			ASC
	)  ON [PRIMARY];

 
CREATE INDEX xif1backup_service_msp ON backup_service_msp
(
       manager_id				ASC
);
go

grant select,insert,update,delete on [dbo].[backup_service_msp]			to [ca_itrm_group]
grant select,insert,update,delete on [dbo].[backup_service_msp]			to [backup_admin_group]
GO

/* ================================================================ */
/* Create new table backup_service_isp							    */
/* ================================================================ */

CREATE TABLE backup_service_isp (
		service_isp_id				binary(16) not null,
		root_service_isp_id			binary(16) null,
		service_msp_id				binary(16) null,
		group_uuid					binary(16) not null,
		name						nvarchar(255) null,
		description					nvarchar(255) collate !!sensitive null,
		notify_method				integer null,
		group_quota					integer null,
		member_quota				integer null,
		used_quota					integer null,	
		last_notify_time			integer null,	
		max_registered_user			integer null,	
		registered_user				integer null,
        trial_to_customer			char(1) null,
        duration_days				integer null,
        start_date					integer null,
        end_date					integer null,
        status						integer null,
        left_space_quota			integer null,
		certificate					nvarchar(255) collate !!sensitive null,
		email_def_id				binary(16) null,
		contact_info				nvarchar(1024) collate !!sensitive null,
		agent_package_url			nvarchar(1024) collate !!sensitive null,
		creation_user				nvarchar(255) collate !!sensitive null, 
		creation_date				integer null,
		last_update_user			nvarchar(255) collate !!sensitive null,
		last_update_date			integer null,
		version_number				integer null,
		);

ALTER TABLE backup_service_isp ADD 
CONSTRAINT XPKbackup_service_isp PRIMARY KEY  CLUSTERED 
	(
		service_isp_id				ASC
	)  ON [PRIMARY];

 
CREATE INDEX xif1backup_service_isp ON backup_service_isp
(
       root_service_isp_id			ASC
);
   	
CREATE INDEX xif2backup_service_isp ON backup_service_isp
(
       service_msp_id				ASC
);

CREATE INDEX xif3backup_service_isp ON backup_service_isp
(
       group_uuid					ASC
);
go

CREATE INDEX xif4backup_service_isp ON backup_service_isp
(
       email_def_id					ASC
);
go

grant select,insert,update,delete on [dbo].[backup_service_isp]			to [ca_itrm_group]
grant select,insert,update,delete on [dbo].[backup_service_isp]			to [backup_admin_group]
GO

/* ================================================================ */
/* Create new table backup_service_administrator				    */
/* ================================================================ */

CREATE TABLE backup_service_administrator (
		service_admin_id			binary(16) not null,
		service_isp_id			binary(16) not null,
		user_uuid					binary(16) null,
		name						nvarchar(255) null,
		password					nvarchar(255) collate !!sensitive null,
		type					char(1) null,
		email_address				nvarchar(255) null,	
		last_login_date				integer null,
		first_login_date			integer null,
		random_password				char(1) null,
		creation_user				nvarchar(255) collate !!sensitive null, 
		creation_date				integer null,
		last_update_user			nvarchar(255) collate !!sensitive null,
		last_update_date			integer null,
		version_number				integer null,
		);

ALTER TABLE backup_service_administrator ADD 
CONSTRAINT XPKbackup_service_administrator PRIMARY KEY  CLUSTERED 
	(
		service_admin_id		ASC
	)  ON [PRIMARY];

 
CREATE INDEX xif1backup_service_administrator ON backup_service_administrator
(
       service_isp_id				ASC
);
CREATE INDEX xif2backup_service_administrator ON backup_service_administrator
(
       user_uuid				ASC
);
   	
go

grant select,insert,update,delete on [dbo].[backup_service_administrator]	to [ca_itrm_group]
grant select,insert,update,delete on [dbo].[backup_service_administrator]	to [backup_admin_group]
GO



/* ================================================================ */
/* Create new table backup_service_link_admin_user		    */
/* ================================================================ */

CREATE TABLE backup_service_link_admin_user (
		service_admin_id			binary(16) not null,
		user_id				binary(16) not null,
		creation_user				nvarchar(255) collate !!sensitive null, 
		creation_date				integer null,
		);

ALTER TABLE backup_service_link_admin_user ADD 
CONSTRAINT XPKbackup_service_link_admin_user PRIMARY KEY  CLUSTERED 
	(
		service_admin_id		ASC,
		user_id		ASC
	)  ON [PRIMARY];

 
CREATE INDEX xif1backup_service_link_admin_user ON backup_service_link_admin_user
(
       service_admin_id				ASC
);
CREATE INDEX xif2backup_service_link_admin_user ON backup_service_link_admin_user
(
       user_id				ASC
);
   	
go

grant select,insert,update,delete on [dbo].[backup_service_link_admin_user]	to [ca_itrm_group]
grant select,insert,update,delete on [dbo].[backup_service_link_admin_user]	to [backup_admin_group]
GO


/* ================================================================ */
/* Create new table backup_staging_server			    */
/* ================================================================ */

CREATE TABLE backup_staging_server (
		staging_server_id			binary(16) not null,
		server_uuid				binary(16) not null,
		network_address				nvarchar(76) null,
		first_run_date				integer null,
		archive_location			nvarchar(255) collate !!sensitive null,
		archive_size				integer null,
		archive_size_used			integer null,	
		user_unprocessed			integer null,
		packages_unprocessed			integer null,
		package_size_unprocessed		integer null,
		history_enabled				integer null,
		status					integer null,
		last_run_date				integer null,	
		creation_user				nvarchar(255) collate !!sensitive null, 
		creation_date				integer null,
		last_update_user			nvarchar(255) collate !!sensitive null, 
		last_update_date			integer null,
		version_number				integer null
		);

ALTER TABLE backup_staging_server ADD 
CONSTRAINT XPKbackup_staging_server PRIMARY KEY  CLUSTERED 
	(
		staging_server_id		ASC
	)  ON [PRIMARY];

 
CREATE INDEX xif1backup_staging_server ON backup_staging_server
(
       server_uuid				ASC
);
   	
go

grant select,insert,update,delete on [dbo].[backup_staging_server]	to [ca_itrm_group]
grant select,insert,update,delete on [dbo].[backup_staging_server]	to [backup_admin_group]
GO


/* ================================================================ */
/* Create new table backup_service_link_isp_server		    */
/* ================================================================ */

CREATE TABLE backup_service_link_isp_server (
		service_isp_id				binary(16) not null,
		server_object_id			binary(16) not null,
		server_object_type			char(1) not null,
		creation_user				nvarchar(255) collate !!sensitive null, 
		creation_date				integer null,
		);

ALTER TABLE backup_service_link_isp_server ADD 
CONSTRAINT XPKbackup_service_link_isp_server PRIMARY KEY  CLUSTERED 
	(
		service_isp_id		ASC,
		server_object_id		ASC
	)  ON [PRIMARY];

 
CREATE INDEX xif1backup_service_link_isp_server ON backup_service_link_isp_server
(
       service_isp_id				ASC
);
CREATE INDEX xif2backup_service_link_isp_server ON backup_service_link_isp_server
(
        server_object_id			ASC,
		server_object_type			ASC
);
   	
go

grant select,insert,update,delete on [dbo].[backup_service_link_isp_server]	to [ca_itrm_group]
grant select,insert,update,delete on [dbo].[backup_service_link_isp_server]	to [backup_admin_group]
GO


/* ================================================================ */
/* Create new table backup_web_service_server			    */
/* ================================================================ */

CREATE TABLE backup_web_service_server (
		web_service_server_id			binary(16) not null,
		manager_id				binary(16) null,
		network_address				nvarchar(76) null,
		status					integer null,
		first_run_date				integer null,
		last_run_date				integer null,
		history_enabled				char(1)	null,
		creation_user				nvarchar(255) collate !!sensitive null, 
		creation_date				integer null,
		last_update_user			nvarchar(255) collate !!sensitive null, 
		last_update_date			integer null,
		version_number				integer null,	
		);

ALTER TABLE backup_web_service_server ADD 
CONSTRAINT XPKbackup_web_service_server PRIMARY KEY  CLUSTERED 
	(
		web_service_server_id		ASC
	)  ON [PRIMARY];

 
CREATE INDEX xif1backup_web_service_server ON backup_web_service_server
(
       web_service_server_id			ASC
);
CREATE INDEX xif2backup_web_service_server ON backup_web_service_server
(
       manager_id				ASC
);
   	
go


grant select,insert,update,delete on [dbo].[backup_web_service_server]	to [ca_itrm_group]
grant select,insert,update,delete on [dbo].[backup_web_service_server]	to [backup_admin_group]
GO




/* =========================================================================== */
/* procedure to increase registered_companies in backup_service_msp table     */
/* =========================================================================== */

CREATE procedure  [dbo].[backup_p_insert_isp_msp_reg_company]
	@_service_msp_id binary(16) 
as
begin
	declare @_registered_companies integer;

	select @_registered_companies = 
		(select bmsp.registered_companies
			 from	backup_service_msp bmsp
			 where	(bmsp.service_msp_id = @_service_msp_id));

	if (@_registered_companies is null) 
	   begin 
		set @_registered_companies = 1;
	   end;	
	else 
	   begin
		set @_registered_companies = @_registered_companies + 1;
		end;	
	  
	update backup_service_msp
  		set registered_companies = @_registered_companies
  		where service_msp_id = @_service_msp_id;
end
GO

grant execute on [dbo].[backup_p_insert_isp_msp_reg_company] to [ca_itrm_group]
grant execute on [dbo].[backup_p_insert_isp_msp_reg_company] to [backup_admin_group]
GO


/*
 *********************************************
 trigger for inserting backup_service_isp entry
 If backup_service_isp is created, backup_service_msp.registered_companies must be increased
*/

CREATE trigger [dbo].[backup_r_insert_isp_msp_reg_company]
			on [dbo].[backup_service_isp]
            after insert
	as
begin
		declare @_service_msp_id binary(16);
		select	@_service_msp_id = (select service_msp_id from inserted);

		if (@_service_msp_id is not null)
		begin
			execute backup_p_insert_isp_msp_reg_company @_service_msp_id;
		end
	end;
GO

/* =========================================================================== */
/* procedure to increase registered_companies in backup_service_msp table     */
/* =========================================================================== */

create procedure  [dbo].[backup_p_delete_isp_msp_reg_company]
	@_service_msp_id binary(16) 
as 
begin
	declare @_registered_companies integer;

	select @_registered_companies = 
		(select bmsp.registered_companies
			 from	backup_service_msp bmsp
			 where	(bmsp.service_msp_id = @_service_msp_id));

	if (@_registered_companies > 0) 
	   begin
		set @_registered_companies = @_registered_companies - 1;
	   end;	
	  
	update backup_service_msp
  		set registered_companies = @_registered_companies
  		where service_msp_id = @_service_msp_id;
end

GO

grant execute on [dbo].[backup_p_delete_isp_msp_reg_company] to [ca_itrm_group]
grant execute on [dbo].[backup_p_delete_isp_msp_reg_company] to [backup_admin_group]
GO

/*
 *********************************************
 trigger for deleting backup_isp entry
 If backup_service_isp is deleted, backup_service_msp.registered_companies must be decreased
*/

CREATE trigger [dbo].[backup_r_delete_isp_msp_reg_company]
			on [dbo].[backup_service_isp]
            after delete
	as
begin
		declare @_service_msp_id binary(16);
		select	@_service_msp_id = (select service_msp_id from deleted);

		if (@_service_msp_id is not null)
		begin		
			execute backup_p_delete_isp_msp_reg_company @_service_msp_id;
		end
	end;
GO


/* =========================================================================== */
/* procedure to increase registered_user in backup_service_isp table         */
/* =========================================================================== */
CREATE procedure  [dbo].[backup_p_insert_user_isp_reg_user]
	@_service_isp_id binary(16) 
as 
begin
	declare @_registered_user integer;

	select @_registered_user = 
	(select bisp.registered_user
		 from	backup_service_isp bisp
		 where	(bisp.service_isp_id = @_service_isp_id));

	if (@_registered_user is null) 
	   begin 
		set @_registered_user = 1;
	   end;	
	else 
	   begin
		set @_registered_user = @_registered_user + 1;
	   end;	
  
	update backup_service_isp
  		set registered_user = @_registered_user
  		where service_isp_id = @_service_isp_id;
	
end
GO

grant execute on [dbo].[backup_p_insert_user_isp_reg_user] to [ca_itrm_group]
grant execute on [dbo].[backup_p_insert_user_isp_reg_user] to [backup_admin_group]
GO

/*
 *********************************************
 trigger for inserting backup_user entry:
 If backup_user is inserted, backup_service_isp.registered user must be increased
*/

CREATE trigger [dbo].[backup_r_insert_user_isp_reg_user]
			on [dbo].[backup_user]
            after insert
	as
    begin
		declare @_service_isp_id binary(16);
		select	@_service_isp_id = (select service_isp_id from inserted);

		if (@_service_isp_id is not null)
		begin
			execute backup_p_insert_user_isp_reg_user @_service_isp_id;
		end;
	end;
GO


/* =========================================================================== */
/* procedure to increase registered_user in backup_service_isp table     */
/* =========================================================================== */
CREATE procedure  [dbo].[backup_p_delete_user_isp_reg_user]
	@_service_isp_id binary(16) 
as
begin
	declare @_registered_user integer;

	select @_registered_user = 
		(select bisp.registered_user
			 from	backup_service_isp bisp
			 where	(bisp.service_isp_id = @_service_isp_id));

	if (@_registered_user > 0) 
	begin
		set @_registered_user = @_registered_user - 1;
  	end;	
  
	update backup_service_isp
		set registered_user = @_registered_user
		where service_isp_id = @_service_isp_id;
end
GO

grant execute on [dbo].[backup_p_delete_user_isp_reg_user] to [ca_itrm_group]
grant execute on [dbo].[backup_p_delete_user_isp_reg_user] to [backup_admin_group]
GO


/*
 *********************************************
 trigger for deleting backup_user entry:
 If backup_user is deleted, backup_service_isp.registered_user must be updated
*/

CREATE trigger [dbo].[backup_r_delete_user_isp_reg_user]
			on [dbo].[backup_user]
            after delete
	as
begin
		declare @_service_isp_id binary(16);
		select	@_service_isp_id = (select service_isp_id from deleted);

		if (@_service_isp_id is not null)
		begin
			execute backup_p_delete_user_isp_reg_user @_service_isp_id;
		end;
	end;
GO



/* =========================================================================== */
/* procedure to update left_space_quota in backup_service_isp table and size   */
/* in backup_archive							       */
/* =========================================================================== */

CREATE  procedure  [dbo].[backup_p_update_user_isp_left_space]
	@_service_isp_id binary(16),
	@_archive_id binary(16)
as
begin
	declare @_left_space_quota integer;
	declare @_archive_size integer;

	if (@_service_isp_id is not null)
	begin
	        select @_left_space_quota = 
		(select round(sum(storage_area_size)/1024, 0)
			 from	backup_user
			 where	service_isp_id = @_service_isp_id);
	
		if (@_left_space_quota is not null)
		begin
			update backup_service_isp
		  		set left_space_quota = @_left_space_quota
		  		where service_isp_id = @_service_isp_id;
		end
	end	

	if (@_archive_id is not null)
	begin
	        select @_archive_size = 
		(select round(sum(storage_area_size)/1024, 0)
			 from	backup_user
			 where	archive_id = @_archive_id);
	
		if (@_archive_size is not null)
		begin
			update backup_archive
		  		set size = @_archive_size
		  		where archive_id = @_archive_id;
		end
	end	

end

GO

grant execute on [dbo].[backup_p_update_user_isp_left_space] to [ca_itrm_group]
grant execute on [dbo].[backup_p_update_user_isp_left_space] to [backup_admin_group]
GO



/*
 *********************************************
 trigger for inserting or updateing backup_user entry:
 If backup_user.storage_area_size is modified the following tables are updated, too:
	1. backup_service_isp.left_space_quota 
	2. backup_archive.size
*/

CREATE  trigger [dbo].[backup_r_update_user_isp_left_space]
			on [dbo].[backup_user]
            after insert, update
	as
begin
		declare @_archive_id binary(16);
		declare @_service_isp_id binary(16);
		declare @_storage_size_old integer;
		declare @_storage_size_new integer;

		select @_service_isp_id = (select service_isp_id from inserted);
		select @_archive_id = (select archive_id from inserted)
		select @_storage_size_old = (select storage_area_size from deleted);
		select @_storage_size_new = (select storage_area_size from inserted);

		if (@_storage_size_new > 0) and
		   (@_storage_size_new != @_storage_size_old)
		begin		
			execute [dbo].[backup_p_update_user_isp_left_space] @_service_isp_id, @_archive_id;
		end;
	end;

GO



/*
 *********************************************
 trigger for deleteing backup_user entry:
 If backup_user is deleted, backup_service_isp.left_space_quota must
 be changed.
*/

CREATE trigger [dbo].[backup_r_delete_user_isp_left_space]
			on [dbo].[backup_user]
            after delete
	as
begin
		declare @_service_isp_id binary(16);
		declare @_archive_id binary(16);
		declare @_storage_size integer;

		select @_service_isp_id = (select service_isp_id from deleted);
		select @_archive_id = (select archive_id from deleted)
		select @_storage_size = (select storage_area_size from deleted);
		
		if (@_storage_size > 0)
		begin
			execute [dbo].[backup_p_update_user_isp_left_space] @_service_isp_id, @_archive_id;
		end;
	end;
GO



/****** Object:  Stored Procedure dbo.backup_p_delete_server    Script Date: 11/13/2007 13:05:10 ******/

/* ================================================================ */
/* procedure to control deleting objects when backup_server exists  */
/* ================================================================ */

create procedure backup_p_delete_server 
	@_server_uuid binary(16)
	as
	begin
		declare @_server_id binary(16);
		declare @_cnt integer;
		
		select @_server_id = (select server_id 
				from backup_server 
				where server_uuid = @_server_uuid);

		if (@_server_id is not null)
		begin
			select @_cnt = (select count(*) 
					from backup_user
					where server_id = @_server_id);
			if (@_cnt != 0)
			begin
				raiserror ('Error 9013: deletion denied, backup_user still exists',16,1); 
			end; 
			else 
			begin
				delete from backup_server where server_id = @_server_id;
				delete from backup_msg_log where server_id = @_server_id;
				delete from backup_statistic where server_id = @_server_id;
				delete from backup_link_backup_policy_server where server_id = @_server_id;
				delete from backup_service_link_isp_server 
					where (server_object_id = @_server_id) and server_object_type = 0;
			end;
		end;
		
		select @_server_id = (select staging_server_id 
				from backup_staging_server 
				where server_uuid = @_server_uuid);

		if (@_server_id is not null)
		begin
			select @_cnt = (select count(*) 
					from backup_user
					where staging_server_id = @_server_id);
			if (@_cnt != 0)
			begin
				raiserror ('Error 9013: deletion denied, backup_user still exists',16,1); 
			end; 
			else 
			begin
				delete from backup_staging_server where staging_server_id = @_server_id;
				delete from backup_statistic where server_id = @_server_id;
				delete from backup_service_link_isp_server 
					where (server_object_id = @_server_id) and server_object_type = 1;
			end;
		end;
		
		 
	end;
GO

grant execute on [dbo].[backup_p_delete_server] to [ca_itrm_group]
grant execute on [dbo].[backup_p_delete_server] to [backup_admin_group]
GO



/*
 *********************************************
 trigger for deleting a ca_server object
*/

create trigger [dbo].[backup_r_del_server_check_bsrv]
            on [dbo].[ca_server]
            after delete
            as
            begin
		declare @_server_uuid binary(16);

		declare lst_uuid cursor for
	       		select server_uuid from deleted;

		-- get first deleted server uuid
		open lst_uuid;
		fetch from lst_uuid into @_server_uuid;

		while @@fetch_status = 0
  		begin
	 		execute [dbo].[backup_p_delete_server] @_server_uuid;
   		     	-- fetch next
   			fetch from lst_uuid into @_server_uuid;
   
		end;  -- end of loop 
  	   
		close lst_uuid;
		deallocate lst_uuid;
                
	   end;

GO



/*
 *********************************************
 trigger for inserting or updateing backup_user entry:
 If backup_user.storage_area_id is modified it must be checked, whether the value is unique
*/

CREATE  trigger [backup_r_update_user_storage_area_id]
			on [dbo].[backup_user]
            after insert, update
	as
begin
		declare @_storage_area_id_old binary(4);
		declare @_storage_area_id_new binary(4);
		declare @_count integer;

		select @_storage_area_id_old = (select storage_area_id from deleted);
		select @_storage_area_id_new = (select storage_area_id from inserted);

		if (@_storage_area_id_new is not null) and
		   (@_storage_area_id_new != @_storage_area_id_old)
		begin
			select @_count = (select count(*) from backup_user 
				where storage_area_id = @_storage_area_id_new);	
			if (@_count > 1)
			begin
				raiserror ('Error xxxx: Unique value for storage_area_id required',16,1); 
			end;
		end;	
	end;

GO


/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                               	*/
/*                                                                                      */
/****************************************************************************************/
insert into mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 values ( 16507685, getdate(), 1, 4, 'Star 16507685 (MODIFIED V4) BABLD: changes for SOA' )
GO

COMMIT TRANSACTION 
GO

