rem @Echo off
REM
REM Name: setupmdb_pre.bat
REM
REM Description:
REM    internal pre-process script for mdb on SQLServer
REM
REM Syntax:
REM
REM    setupmdb_pre
REM
REM History:
REM    17-jul-2006  mulwi01  created
REM    21-jul-2006  mulwi01  removed version/upgrade check
REM    30-mar-2006  hopst01  added support for windows or sql authentication
REM    31-aug-2007  johri05  16212586  27Jul07 MODIFICATIONS TO UPGRADE PROC
REM                           If database is 1.0.4 then run CumulativePatch.
REM    19-sep-2007  hopst01  If database version is 1.0.5 or greater don't
REM                              exit with error
REM    19-sep-2007  johri05  b1236 -pre-check environment option
REM    22-sep-2007  hopst01  remove double quotes from pre-check file
REM     6-nov-2007  hopst01  b1636 Add precheck call to Java to setupmdb.  
REM                               Remove printing of ERR_MESSAGE as java 
REM                               check in setupmdb might change the value
REM    20-nov-2007  hopst01  b1637 Integrate windows scripts with status log
REM    29-nov-2007  johri05  b1628 Consistency of logged messages time stamps
REM                      Add :GET_DT--Get Date/Time func to fmt logged timestamp
REM                      to match Java Utilities and LinuxUnix install scripts.
REM    11-dec-2007  hopst01  b1675 Pass additional params to PatchMDB: port, username/password
REM    14-dec-2007  johri05  b1628 Consistency of logged messages time stamps
REM                      Copy fixed :GET_DT func from setupmdb.bat
REM                      Fixed :GET_DT--"Get Date/Time" func, to always use 24-hr fmt
REM                      Also fixed to use %TMPDIR% for temporary (writable) directory.
REM    21-dec-2007  hopst01  16587331 - Update precheck messages
REM    23-jan-2008  hopst01           - NSM reported install problem, when install on ghost
REM                                     and port used is 0. Sol'n: don't pass 0 to PatchMDB
REM    19-feb-2008  hopst01  Ensure that debug level is restore after call to PatchMDB
REM    08-apr-2008  hopst01  b1693 Ensure that database is case insensitive before installing 
REM    16-apr-2008  hopst01  As a part of porting manual 1.0.4 patch, do not pass
REM                          port to PatchMDB if DBMS_INSTNCE_PATCH is blank, this
REM                          usage is no longer supported
REM    24-apr-2008  hopst01  17062824 - Connect to database when retrieving database information
REM                          db information will not be available if database is close.  This is
REM                          is the case of sql server express and auto close. Copy LoadMDBUtil for precheck
REM    13-may-2008  hopst01  b1840 - New API to patchmdb
REM    14-jul-2008  hopst01  b1766 - PRECHECK FAILURE (Star 17044308). Always copy precheck files.
REM    18-jul-2008  hopst01  Star 17294367 DBPASSWORD WITH "," FAILED. Treat DBPASSWORD like 
REM                          MDB_ADMIN_PSWD.  Use temp variable when comparing it to an 
REM                          empty string.
REM    05-aug-2008  hopst01  b1917 - STAR 17340801 Use TCP connection host,port unless 
REM                          port is 0 this replaces dbhost in the connection string 
REM    06-aug-2008  hopst01  STAR 17177592 - Conversion unnecessary.  If MDB 1.0.4 present only install
REM                          MDB Base 1.5 schema. If 1.5 database is 1.0.4 compatible don't 
REM                          process any XML files. Add mdb_version check and setting of 
REM                          flags MDB_VERSION_EXIST and IS_104_COMPATIBLE
REM    08-aug-2008  johri05  b1882-17149528-MDBTOOLS DATE TIME ERROR LOG
REM                          Fix to use only minimal short format to prefix logged messages.
REM                          Long format is to be used once in the install log header.
REM                             long fmt:  yyyy-MMM-dd,HH:mm:ss-zzzz -ex:2008-jul-04,15:30:00-0400
REM                             short fmt:       MM-dd,HH:mm:ss      -ex:      07-04,15:30:00
REM                          Del :GET_DT function
REM                          Chg calls to :GET_DT label to be calls to mdbFuncs with GET_DT argument
REM    11-aug-2008  hopst01  b1882-17149528-MDBTOOLS DATE TIME ERROR LOG. Target Directory needs to 
REM                          be quoted. Don't pipe calls to mdbFuncs to nul as it makes debug impossible.
REM    12-aug-2008  hopst01  Star 17330984-INSTALL FAILS AFTER EXPORT. Update error message when unable to 
REM                          determine the version of the MDB. 
REM    13-aug-2008  hopst01  Star 17401377-WRONG MSG DURING PRCHK FAIL. Handle negative return codes from
REM                          SQLServer command line utility.
REM    27-oct-2008  hopst01  Star 17585716 - UPGRADE FAILS WITH RETURN CODE. Check for only case insensitive attribute.
REM                          Do not match language and accent sensitivity.
REM    24-nov-2008  hopst01  STAR 17651895 - Verify that installing into dbo schema.
REM    05-dec-2008  hopst01  17727007 - FOR LOOP W CMD NOT SUPPORTED. For loops that use 
REM                          a command to populate the for loop set should be replaced.  
REM    09-jan-2009 lupmo01  17826194: read port number from registry for the local default instance of SQL Server 
REM			    in case DBPORT is not specified or it is zero
REM    15-Jun-2009 kansa04  18212541: The mdb installtion is failing for non-default port for default mssql instance	
REM    19-Jun-2009 hopst01  18212541: syntax fix
REM	   28-Dec-2012 agrga03  Star 21243492: DATABASE NAME WITH HYPHEN(-)
REM

set MDB_RC=2

rem
rem No log file while pre-checking.
rem
IF /I  "%PRECHECK%" == "yes"   set LOGFILE=nul

set DBMS_INSTANCE_PATCH=

IF "%DBHOST%"=="" GOTO DONE_SET_INSTANCE
IF "%DBHOST%"=="local" GOTO DONE_SET_INSTANCE
IF "%DBHOST%"=="localhost" GOTO NOREMOTE
set DBMS_INSTANCE_PATCH=-DBMS_INSTANCE="%DBHOST%"

:NOREMOTE
rem 17826194 - read the port number of the default instance from registry

set SERVER_NAME=%DBHOST%
set IS_LOCAL=0
set IS_DEFAULT_INSTANCE=0
set INSTANCE_NAME=

if /I "%DBHOST%"=="localhost" GOTO NOREMOTE_CASE
GOTO CHECK_DBPORT

:NOREMOTE_CASE
set SERVER_NAME=localhost
set IS_LOCAL=1

:CHECK_DBPORT
if ("%DBPORT%") EQU ("") GOTO READ_DBPORT
if ("%DBPORT%") EQU ("0") GOTO READ_DBPORT
GOTO DONE_READ_DBPORT

:READ_DBPORT
for /F "tokens=1* delims=\" %%A in ("%SERVER_NAME%") DO CALL :GET_SERVER_NAME %%A %%B

if (%INSTANCE_NAME%)==() set IS_DEFAULT_INSTANCE=1

IF /I "%COMPUTERNAME%"=="%SERVER_NAME%" set IS_LOCAL=1
REM 18212541 issue starts
set CLUSTER_CMD=cluster.exe
%CLUSTER_CMD%  -? > nul 2>&1
IF %ERRORLEVEL% EQU 9009 (
                set CLUSTER_CMD="%windir%\system32\cluster.exe"
                )

%CLUSTER_CMD%  -? > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
                %CLUSTER_CMD% /version | find /I "%SERVER_NAME%" > nul 2>&1
                IF %ERRORLEVEL% EQU 0 set IS_LOCAL=1
)
REM 18212541 issue ends
IF %IS_LOCAL% EQU 0 GOTO DONE_READ_DBPORT
IF %IS_DEFAULT_INSTANCE% EQU 0 GOTO DONE_READ_DBPORT

:READ_TCP_PORT

rem find SQL Server listening port number for the default instance

set REG_OUTPUT_FILE=%TMPDIR%\regout.reg
set REG_OUTPUT_FILE_ANSI=%TMPDIR%\regout.txt
set TCP_PORT=
set CA_TCP_PORT_KEY=HKEY_LOCAL_MACHINE\SOFTWARE\MICROSOFT\MSSQLSERVER\MSSQLSERVER\SUPERSOCKETNETLIB\TCP

rem
rem get proper regedit command, regedit doesn't fail for non-existent keys
rem 
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
IF EXIST "%REG_OUTPUT_FILE_ANSI%" DEL "%REG_OUTPUT_FILE_ANSI%" > nul 2>&1
SET REG_CMD=regedit.exe
rem force 0 command line errorcode
cd > nul 2>&1

%REG_CMD% /e "%REG_OUTPUT_FILE%" "noknownkey" > nul 2>&1
IF %ERRORLEVEL% EQU 0 GOTO GET_TCP_PORT

IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
set REG_CMD="%windir%\regedit.exe"
cd > nul 2>&1
%REG_CMD% /e "%REG_OUTPUT_FILE%" "noknownkey" > nul 2>&1
IF %ERRORLEVEL% EQU 0 GOTO GET_TCP_PORT

set MDBRC=805
set ERR_MESSAGE=Unable to find regedit.exe, please add it to the path
GOTO DONE_READ_DBPORT

:GET_TCP_PORT

%REG_CMD% /e "%REG_OUTPUT_FILE%" "%CA_TCP_PORT_KEY%" 
IF NOT EXIST "%REG_OUTPUT_FILE%" GOTO DONE_GET_TCP_PORT

type "%REG_OUTPUT_FILE%" > "%REG_OUTPUT_FILE_ANSI%"
IF NOT EXIST "%REG_OUTPUT_FILE_ANSI%" GOTO DONE_GET_TCP_PORT

for /F "usebackq tokens=1,2* delims==" %%i IN ("%REG_OUTPUT_FILE_ANSI%") DO IF("%%i") EQU (""TcpPort"") SET TCP_PORT=%%j

:DONE_GET_TCP_PORT
IF EXIST "%REG_OUTPUT_FILE%" DEL "%REG_OUTPUT_FILE%" > nul 2>&1
IF EXIST "%REG_OUTPUT_FILE_ANSI%" DEL "%REG_OUTPUT_FILE_ANSI%" > nul 2>&1

set temp_tcp=x%TCP_PORT%x
set temp_tcp=%temp_tcp:"=%
IF ("%temp_tcp%") EQU ("xx") GOTO :ERROR_READING_TCP_PORT

SET TCP_PORT=%TCP_PORT:"=%
IF ("%TCP_PORT%") NEQ ("") set DBPORT=%TCP_PORT%

echo %DT% Using port %TCP_PORT% to access local default instance. >> %LOGFILE% 2>&1
GOTO :DONE_READ_DBPORT

:ERROR_READING_TCP_PORT
echo %DT% Error getting the port number from registry to access the local default instance. >> %LOGFILE% 2>&1

:DONE_READ_DBPORT
rem 17826194 - END

set DBMS_INSTANCE=%DBHOST%
IF ("%DBPORT%") NEQ ("") IF ("%DBPORT%") NEQ ("0") SET DBMS_INSTANCE=%DBMS_INSTANCE%,%DBPORT%
SET DBMS_INSTANCE="%DBMS_INSTANCE%"
:DONE_SET_INSTANCE

REM  expects imported %DBVENDOR%
REM  expects imported %DBNAME%
REM  expects imported %PRECHECK% and %PRECHECK_MSGFILE%
REM ... also perhaps these are expected imports...
rem     set MDB_SOURCE_DIR=%~1
rem     set MDB_TARGET_DIR=%~1
rem     set MDB_PATCH_DIR=%~1
rem     IF NOT "%~1"=="yes" GOTO CHECK_NO
rem     set EXIT_SCRIPT=/B
rem     set DBUSER=%~1
rem     set DBPASSWORD=%~1
rem     set HASPORT=1
rem     set DBPORT=%~1

rem
rem Get TMPDIR for general use. (use tgt dir for pre-script)
rem This script may require tgt dir to be current dir.
rem  (current dir used as temporary before chdir)
rem
set TMPDIR=%MDB_TARGET_DIR%

rem
rem Check if SQLServer is available
rem
sqlcmd -? > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
    set SQL_CMD=sqlcmd
    GOTO OSQL_FOUND
)
osql -? > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
    set SQL_CMD=osql
    GOTO OSQL_FOUND
)

set MDB_RC=10
set ERR_MESSAGE=cannot find osql or sqlcmd. Check that SQLServer has been installed and in the PATH
GOTO DONE_EXIT
:OSQL_FOUND

rem
rem determine if using windows or sql server authentication
rem
set AUTH=-E
set ECHOED_AUTH=-E
set AUTHENTICATION_TYPE=WIN
SET T_DBPASSWORD=x%DBPASSWORD%x
SET T_DBPASSWORD="%T_DBPASSWORD:"=%"
IF (%DBUSER%) NEQ () IF (%T_DBPASSWORD%) NEQ ("xx") GOTO SQL_AUTH
GOTO AUTH_SET
:SQL_AUTH
set AUTH=-U %DBUSER% -P %DBPASSWORD_DQ%
set ECHOED_AUTH=-U %DBUSER% -P ***
set AUTHENTICATION_TYPE=SQL
:AUTH_SET


rem
rem copy for precheck
rem
IF /I "%PRECHECK%" == "yes" IF /I NOT "%MDB_TARGET_DIR%" == "%MDB_SOURCE_DIR%" xcopy "%MDB_SOURCE_DIR%\%DBVENDOR%\precheck_extension.bat" .\  /Q /Y /R > nul 2>&1
IF /I "%PRECHECK%" == "yes" IF /I NOT "%MDB_TARGET_DIR%" == "%MDB_SOURCE_DIR%" xcopy "%MDB_SOURCE_DIR%\%DBVENDOR%\LoadMDBUtil.exe" .\  /Q /Y /R > nul 2>&1

REM
REM check if mdb already exists
REM
IF /I  "%PRECHECK%" == "yes"   goto SKIP_ECHO
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% Checking if %DBNAME% already exists...
echo %DT% Checking if %DBNAME% already exists...      >> %LOGFILE% 2>&1
echo %DT%                                             >> %LOGFILE%
echo %DT% %SQL_CMD% -S %DBMS_INSTANCE% -d master %ECHOED_AUTH% -e -b -Q "exit(SELECT count(*)+100000 FROM master..sysdatabases WHERE name = '%DBNAME%')"    >>%LOGFILE% 2>&1
:SKIP_ECHO

%SQL_CMD% -S %DBMS_INSTANCE% -d master %AUTH% -e -b -Q "exit(SELECT count(*)+100000 FROM master..sysdatabases WHERE name = '%DBNAME%')"               >> %LOGFILE% 2>&1
set RC=%ERRORLEVEL%
IF %RC% NEQ 100000 GOTO MDB_MAYBE_FOUND
IF /I  NOT "%PRECHECK%" == "yes"   goto MDB_NOT_FOUND
set MDB_RC=0
set ERR_MESSAGE=Pre-check OKAY ( will install new MDB database )
 
GOTO DONE_EXIT

:MDB_MAYBE_FOUND
IF %RC% EQU 100001 GOTO MDB_EXISTS
set ERR_MESSAGE=SQL command error, ERRORLEVEL=%RC%, unable to connect to master database
IF /I  NOT "%PRECHECK%" == "yes"   set ERR_MESSAGE=SQL command error, ERRORLEVEL=%RC%, see logfile for details

set MDB_RC=100
GOTO DONE_EXIT


:MDB_EXISTS
set DB_CREATED=false

REM
REM Ensure that the database that we're installing against is case-insensitive
REM
IF EXIST db_collation.txt DEL db_collation.txt
:GET_DATABASE_COLLATION
IF %SQL_CMD% EQU sqlcmd (
	%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% %AUTH% -h-1 -s. -b /Q  "select 'collation=' + convert(varchar(60), databasepropertyex('%DBNAME%', 'COLLATION'))" > db_collation.txt
) ELSE (
	%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% %AUTH% -h-1 -s. -n -b /Q  "select 'collation=' + convert(varchar(60), databasepropertyex('%DBNAME%','COLLATION'))" > db_collation.txt
)
set RC=%ERRORLEVEL%
IF %RC% EQU 0 GOTO PARSE_COLLATION
set MDB_RC=106
set ERR_MESSAGE=Failed to determine the database collation (errorlevel=%ERRORLEVEL%)
GOTO DONE_EXIT

rem Parse the database collation
:PARSE_COLLATION
SET DB_COLLATION=

IF NOT EXIST db_collation.txt GOTO FAIL_FETCH_DB_COL
for /F "tokens=1,2 delims==" %%i IN (db_collation.txt) DO IF ("%%i") EQU ("collation") SET DB_COLLATION=%%j 
IF ("%DB_COLLATION%") EQU ("") GOTO FAIL_FETCH_DB_COL
SET DB_COLLATION=%DB_COLLATION: =%
GOTO VERIFY_COL_CLEANUP
:FAIL_FETCH_DB_COL
set MDB_RC=107
set ERR_MESSAGE=Failed to determine the database collation (errorlevel=%ERRORLEVEL%)
GOTO VERIFY_COL_CLEANUP

:VERIFY_COL_CLEANUP
IF EXIST db_collation.txt DEL db_collation.txt
IF ("%DB_COLLATION%") NEQ ("") GOTO VERIFY_COL 
GOTO DONE_EXIT

:VERIFY_COL
CALL :GET_CASE_ATTR %DB_COLLATION% 
IF "%IS_CS%" EQU "no" GOTO CHECK_DEFAULT_SCHEMA

set ERR_MESSAGE=Cannot install into database %DBNAME% because it uses non case insensitive collation
IF ("%DB_COLLATION%") NEQ ("") set ERR_MESSAGE=%ERR_MESSAGE%, '%DB_COLLATION%'
IF "%T_ERR_MESSAGE%" NEQ "" set ERR_MESSAGE=%T_ERR_MESSAGE%	

IF /I  "%PRECHECK%" == "yes" GOTO VERIFY_COL_ECHO_SKIP
echo %ERR_MESSAGE% >> %LOGFILE% 2>&1
:VERIFY_COL_ECHO_SKIP
IF "%T_RC%" EQU "" (
	set MDB_RC=109
) ELSE (
	set MDB_RC=%T_RC%
)

GOTO DONE_EXIT

:PARSE_COLLATION_STR_ERR
SET MDB_RC=T_RC
SET ERR_MESSAGE=T_ERR_MESSAGE
GOTO DONE_EXIT

REM
REM Verify that the schema will be installed in dbo schema
REM
:CHECK_DEFAULT_SCHEMA

rem
rem Determine which version SQL Server we're running against
rem 
SET VERSION_FILE=version.txt
IF EXIST %VERSION_FILE% DEL %VERSION_FILE%
%SQL_CMD% -S %DBMS_INSTANCE% -d master %AUTH% -h-1 -s. -b /Q  "select convert(varchar(20), serverproperty('productversion'))" > %VERSION_FILE%
for /F "usebackq" %%a in (%VERSION_FILE%) do (
  set SQLSERVER_VERSION=%%a
  goto ENDFOR
)
:ENDFOR
set SQLSERVER_VERS=%SQLSERVER_VERSION:~0,1%
del version.txt
if "%SQLSERVER_VERS%" == "7" goto SQLSERVER_2000_OR_LESS
if "%SQLSERVER_VERS%" == "8" goto SQLSERVER_2000_OR_LESS
GOTO SQLSERVER_2005_OR_HIGHER

:SQLSERVER_2000_OR_LESS
SET SCHEMA_QUERY=SELECT 'schema=' + name FROM sysusers WHERE name = USER_NAME()
GOTO QUERY_SCHEMA

:SQLSERVER_2005_OR_HIGHER
SET SCHEMA_QUERY=SELECT 'schema=' + default_schema_name FROM sys.database_principals WHERE principal_id = DATABASE_PRINCIPAL_ID()
GOTO QUERY_SCHEMA

:QUERY_SCHEMA
IF EXIST %VERSION_FILE% DEL %VERSION_FILE%
SET DEF_SCHEMA_FILE=default_schema.txt
IF EXIST %DEF_SCHEMA_FILE% del %DEF_SCHEMA_FILE%
IF %SQL_CMD% EQU sqlcmd (
	%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% %AUTH% -h-1 -s. -b /Q "%SCHEMA_QUERY%"    >> %DEF_SCHEMA_FILE% 2>&1
) ELSE (
	%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% %AUTH% -h-1 -s. -n -b /Q "%SCHEMA_QUERY%"    >> %DEF_SCHEMA_FILE% 2>&1
)
SET RC=%ERRORLEVEL%
IF %RC% EQU 0 GOTO PARSE_DEFAULT_SCHEMA 
SET MDB_RC=132
SET ERR_MESSAGE=Error parsing default schema for installation user.
GOTO DONE_EXIT

:PARSE_DEFAULT_SCHEMA
SET DB_SCHEMA=
for /F "usebackq tokens=1,2 delims==" %%i IN (%DEF_SCHEMA_FILE%) DO IF ("%%i") EQU ("schema") SET DB_SCHEMA=%%j
SET T_DB_SCHEMA=x%DB_SCHEMA%x
IF "%T_DB_SCHEMA%" EQU "xx" GOTO PARSE_DEFAULT_SCHEMA_ERR
SET DB_SCHEMA=%DB_SCHEMA: =%
SET T_DB_SCHEMA=x%DB_SCHEMA%x
IF "%T_DB_SCHEMA%" EQU "xx" SET DB_SCHEMA= && GOTO PARSE_DEFAULT_SCHEMA_ERR
IF "%DB_SCHEMA%" EQU "dbo" GOTO CHECK_MDB_VERSION

:PARSE_DEFAULT_SCHEMA_ERR  
SET ERR_MESSAGE=Default schema of the installation user must be dbo.
SET MDB_RC=131
IF NOT EXIST %DEF_SCHEMA_FILE% GOTO CHECK_DEFAULT_SCHEMA_ERR  
IF ("%DB_SCHEMA%") NEQ ("") IF ("%DB_SCHEMA%") NEQ (" ") SET ERR_MESSAGE=%ERR_MESSAGE% Current user has default schema of %DB_SCHEMA%. 
:CHECK_DEFAULT_SCHEMA_ERR
GOTO DONE_EXIT

REM
REM check the existing mdb version
REM
:CHECK_MDB_VERSION
IF /I  "%PRECHECK%" == "yes"   goto SKIP_ECHO2
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT%                                             >> %LOGFILE%
echo %DT% Checking existing %DBNAME% version...
echo %DT% Checking existing %DBNAME% version...       >> %LOGFILE% 2>&1
echo %DT%                                             >> %LOGFILE%
:SKIP_ECHO2
rem
rem Determine if the MDB Version table exists
rem
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% %AUTH% -e -b -Q "exit(select (mdbmajorversion * 100) + mdbminorversion  + 2 from mdb_version)"                            >> %LOGFILE% 2>&1
set RC=%ERRORLEVEL%
IF %RC% GTR 0 IF %RC% NEQ 1 IF %RC% NEQ 3 SET MDB_VERSION_EXIST=yes

rem
rem One line command exits with single value for the major/minor version.
rem The major version is scaled by 100 and the minor is added (e.g. 1.4 is 104)
rem
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% %AUTH% -e -b -Q "exit(select (mdbmajorversion * 100) + mdbminorversion from mdb)"                            >> %LOGFILE% 2>&1
set RC=%ERRORLEVEL%
IF %RC% EQU 1 GOTO MDB_VER_ERROR
IF %RC% EQU 104 SET IS_104_COMPATIBLE=yes&& GOTO MDB_104_EXISTS

set MDB_RC=200
IF %RC% GEQ 105 SET MDB_RC=0
set ERR_MESSAGE=Pre-check OKAY ( will upgrade MDB version-1.5 )
IF %RC% LEQ 0   SET ERR_MESSAGE=%SQL_CMD% error checking MDB version(rc=%RC%). Unable to gather version information from mdb table. 
GOTO DONE_EXIT

:MDB_VER_ERROR
rem Unexpected SQL command error.
set MDB_RC=101
set ERR_MESSAGE=%SQL_CMD% error checking MDB version(rc=%RC%). Unable to query the mdb table.
IF /I  NOT "%PRECHECK%" == "yes"  set ERR_MESSAGE=%ERR_MESSAGE% ... see logfile for details.

GOTO DONE_EXIT

:MDB_104_EXISTS
set MDB_RC=0
set ERR_MESSAGE=Pre-check OKAY ( will upgrade MDB which has version-1.0.4 )



REM
REM Pre-check stops here.
REM
IF /I  NOT "%PRECHECK%" == "yes"   goto NOT_PRECHECK
set MDB_RC=0
set ERR_MESSAGE=Pre-check OKAY ( will upgrade MDB which has version-1.0.4 ) 
GOTO DONE_EXIT
:NOT_PRECHECK


REM
REM Apply MDB 1.0.4 Cumulative Patch.
REM
GOTO APPLY_PATCH



:MDB_NOT_FOUND
REM
REM no existing mdb, create it
REM

IF %SQL_CMD% EQU sqlcmd (
    %SQL_CMD% -S %DBMS_INSTANCE% -h-1 -s. %AUTH% -b /Q  "select convert(varchar(60), serverproperty('COLLATION'))" > collation.txt
) ELSE (
    %SQL_CMD% -S %DBMS_INSTANCE% -h-1 -s. -n %AUTH% -b /Q  "select convert(varchar(60), serverproperty('COLLATION'))" > collation.txt
)
IF %ERRORLEVEL% EQU 0 GOTO DB_COLLATION
set MDB_RC=300
set ERR_MESSAGE=Failed to determine the collation (errorlevel=%ERRORLEVEL%)
GOTO DONE_EXIT
:DB_COLLATION

call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% Creating %DBNAME%...
echo %DT%                                             >> %LOGFILE% 2>&1
echo %DT% Creating %DBNAME%...                        >> %LOGFILE% 2>&1

REM	 Star 21243492: DATABASE NAME WITH HYPHEN(-) - Added Square brackets to handle hyphen in dbname

set TMPSQL=create_sql_%DBNAME%.sql
if exist %TMPSQL% del %TMPSQL%
echo create database [%DBNAME%]                  >> %TMPSQL%
LoadMDBUtil -mdb %TMPSQL% collation.txt
echo go                            >> %TMPSQL%
echo use [%DBNAME%]                     >> %TMPSQL%
echo go                            >> %TMPSQL%

echo ALTER DATABASE [%DBNAME%]                   >> %TMPSQL%
echo    SET RECURSIVE_TRIGGERS ON                 >> %TMPSQL%
echo go                            >> %TMPSQL%

echo sp_configure 'show advanced option', '1'                   >> %TMPSQL%
echo go                            >> %TMPSQL%
echo RECONFIGURE                      >> %TMPSQL%
echo go                            >> %TMPSQL%
echo sp_configure                     >> %TMPSQL%
echo go                            >> %TMPSQL%
IF %SQL_CMD% EQU sqlcmd (
    echo exit                         >> %TMPSQL%
)
if exist collation.txt del collation.txt

call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT%                                             >> %LOGFILE%
echo %DT% %SQL_CMD% -S %DBMS_INSTANCE% -d master %ECHOED_AUTH% -e -b [%TMPSQL%]   >>%LOGFILE% 2>&1

%SQL_CMD% -S %DBMS_INSTANCE% -d master %AUTH% -e -b <%TMPSQL%         >> %LOGFILE% 2>&1
IF %ERRORLEVEL% EQU 0 GOTO DB_CREATED
set MDB_RC=400
set ERR_MESSAGE=Failed to create the database (errorlevel=%ERRORLEVEL%)
if exist %TMPSQL% del %TMPSQL%
GOTO DONE_EXIT
:DB_CREATED
if exist %TMPSQL% del %TMPSQL%
set DB_CREATED=true

set MDB_RC=0
set ERR_MESSAGE=Created the %DBNAME% database
CALL :INCREMENT_STATUS 3
GOTO DONE_EXIT


:APPLY_PATCH
rem
rem Apply the MDB 1.04 Cumulative Patch.
rem
CALL :INCREMENT_STATUS 1
IF NOT EXIST "%MDB_TARGET_DIR%\%DBVENDOR%\CumulativePatch" GOTO NO_PATCH_DIRS
IF NOT EXIST "%MDB_TARGET_DIR%\%DBVENDOR%\CumulativePatch\GetPatchNumber.bat" GOTO NO_PATCH_NUM
IF NOT EXIST "%MDB_TARGET_DIR%\%DBVENDOR%\CumulativePatch\PatchMDB.bat" GOTO NO_PATCH_MDB
IF NOT EXIST "%MDB_SOURCE_DIR%\%DBVENDOR%\CumulativePatch\patches" GOTO NO_PATCH_DIRS
rem
rem Apply cumulative patch
rem
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% Applying cumulative patch...
echo %DT% Applying cumulative patch...                >> %LOGFILE%

chdir /D "%MDB_TARGET_DIR%\%DBVENDOR%\CumulativePatch"         >> %LOGFILE% 2>&1

set PATCH_ARGS=
set ECHO_PATCH_ARGS=
IF ("%DBMS_INSTANCE_PATCH%") EQU ("") GOTO SKIP_PORT
IF ("%DBPORT%") NEQ ("") IF ("%DBPORT%") NEQ ("0") SET PATCH_ARGS=-DBPORT=%DBPORT%
:SKIP_PORT
SET ECHO_PATCH_ARGS=%PATCH_ARGS%
IF ("%AUTH%")   NEQ ("-E") SET PATCH_ARGS=%PATCH_ARGS% -DBUSER=%DBUSER% -DBPASSWORD=%DBPASSWORD_DQ%
IF ("%AUTH%")   NEQ ("-E") SET ECHO_PATCH_ARGS=%ECHO_PATCH_ARGS% -DBUSER=%DBUSER% -DBPASSWORD=****
call GetPatchNumber MDB_CUMULATIVE_PATCH                 >> %LOGFILE% 2>&1
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
set T_EXIT_SCRIPT=%EXIT_SCRIPT%
echo %DT% call PatchMDB %DBMS_INSTANCE_PATCH% -MDB_NAME=%DBNAME% -MDB_PATCH=%MDB_CUMULATIVE_PATCH% %ECHO_PATCH_ARGS% -MDB_EXIT_SCRIPT=yes                                >> %LOGFILE% 2>&1
call PatchMDB %DBMS_INSTANCE_PATCH% -MDB_NAME=%DBNAME% -MDB_PATCH=%MDB_CUMULATIVE_PATCH% %PATCH_ARGS% -MDB_EXIT_SCRIPT=yes
set T_RC=%ERRORLEVEL%
set EXIT_SCRIPT=%T_EXIT_SCRIPT%
%DEBUGECHO%
IF %T_RC% EQU 0 GOTO PATCH_OK
set MDB_RC=600
set ERR_MESSAGE=Failed to apply patch %MDB_CUMULATIVE_PATCH% on database %DBNAME% (errorlevel=%ERRORLEVEL%)
GOTO DONE_EXIT

:PATCH_OK
CALL :INCREMENT_STATUS 5
set MDB_RC=0
set ERR_MESSAGE=setupmdb_pre completed for the %DBNAME% database.

GOTO DONE_EXIT

:NO_PATCH_NUM
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% ERROR: cannot apply cumulative patch because "%MDB_TARGET_DIR%\CumulativePatch\GetPatchNumber.bat" is NOT found
echo %DT% ERROR: cannot apply cumulative patch because "%MDB_TARGET_DIR%\CumulativePatch\GetPatchNumber.bat" is NOT found  >> %LOGFILE%
set MDB_RC=601
set ERR_MESSAGE=Failed to apply patch %MDB_CUMULATIVE_PATCH% on database %DBNAME% (see %LOGFILE%)
GOTO DONE_EXIT

:NO_PATCH_MDB
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% ERROR: cannot apply cumulative patch because "%MDB_TARGET_DIR%\CumulativePatch\PatchMDB.bat" is NOT found
echo %DT% ERROR: cannot apply cumulative patch because "%MDB_TARGET_DIR%\CumulativePatch\PatchMDB.bat" is NOT found    >> %LOGFILE%
set MDB_RC=602
set ERR_MESSAGE=Failed to apply patch %MDB_CUMULATIVE_PATCH% on database %DBNAME% (see %LOGFILE%)
GOTO DONE_EXIT

:NO_PATCH_DIRS
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% ERROR: Patch dir missing.  Cannot apply cumulative patch.
echo %DT% ERROR: Patch dir missing.  Cannot apply cumulative patch.  >> %LOGFILE%
set MDB_RC=603
set ERR_MESSAGE=Failed to apply patch %MDB_CUMULATIVE_PATCH% on database %DBNAME% (see %LOGFILE%)
GOTO DONE_EXIT


REM
REM Create the mdb signature for asset/patch management
REM
if "%AUTHENTICATION_TYPE%"=="WIN" GOTO SIGWIN
call .\%DBVENDOR%\CreateMDBSignature %DBMS_INSTANCE_PATCH% -MDB_NAME=%DBNAME% -DBUSER=%DBUSER% -DBPASSWORD=%DBPASSWORD_DQ%                        >> %LOGFILE% 2>&1
GOTO SIGEND

:SIGWIN
call .\%DBVENDOR%\CreateMDBSignature %DBMS_INSTANCE_PATCH% -MDB_NAME=%DBNAME% >>%LOGFILE% 2>&1

:SIGEND
set MDB_RC=0



:DONE_EXIT
REM
REM Handle precheck output.
REM
IF /I  NOT "%PRECHECK%" == "yes"   goto NORM_DONE_EXIT
IF %MDB_RC% EQU 0 CALL :PRECHECK_EXT
GOTO FINI

:NORM_DONE_EXIT
chdir /D "%MDB_TARGET_DIR%"                                    >> %LOGFILE% 2>&1
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% %ERR_MESSAGE%
echo %DT% %ERR_MESSAGE%                               >> %LOGFILE% 2>&1
echo %DT% Setupmdb_pre exit /B return code=%MDB_RC%   >> %LOGFILE% 2>&1

:FINI
EXIT /B %MDB_RC%

rem
rem Additional prechecks that are not a part of the install process are
rem performed here.  The script sets both the return code and the err_message
rem
:PRECHECK_EXT
IF NOT EXIST precheck_extension.bat GOTO PRECHECK_EXT_ERR
call precheck_extension
GOTO DONE_PRECHECK_EXT
:PRECHECK_EXT_ERR
set MDB_RC=3
set ERR_MESSAGE=Could not find file %CD%\precheck_extension.bat
:DONE_PRECHECK_EXT
GOTO :EOF

:INCREMENT_STATUS
set /A STATUS=%STATUS% + %1%
rem
rem set SPACES to 1 or 2 spaces depending on the current status
rem value.  although quotes are unnessary, they make the reading
rem of the value easier
rem
set SPACES="  "
IF %STATUS% GTR 9 set SPACES=" "
rem strip quotes
set SPACES=%SPACES:"=%
echo %SPACES%%STATUS%%% %STATUSLINE% > %STATUSFILE%
GOTO :EOF

:GET_CASE_ATTR
set COLLATION_STRING=%1%
set B_COLLATION_STRING=
CALL :REVERSE %COLLATION_STRING% B_COLLATION_STRING
set CASE_TOKEN_CAR=%B_COLLATION_STRING%
set CASE_TOKEN_CDR=
set IS_CS=
SET T_RC=
SET T_ERR_MESSAGE=
for /F "usebackq eol=# tokens=1* delims=_" %%i in ('%CASE_TOKEN_CAR%') do CALL :GET_CASE_TOKEN %%i %%j
IF "%CASE_TOKEN_CAR%" EQU "NIB" GOTO SET_SENSITIVE
IF "%CASE_TOKEN_CAR%" EQU "2NIB" GOTO SET_SENSITIVE
IF "%CASE_TOKEN_CAR%" EQU "SW" GOTO GET_KANA_ACC
IF "%CASE_TOKEN_CAR%" EQU "IW" GOTO GET_KANA_ACC
IF "%CASE_TOKEN_CAR%" EQU "SK" GOTO GET_ACC
IF "%CASE_TOKEN_CAR%" EQU "IK" GOTO GET_ACC
IF "%CASE_TOKEN_CAR%" EQU "SA" GOTO GET_CS
IF "%CASE_TOKEN_CAR%" EQU "IA" GOTO GET_CS
GOTO ERR_GET_CASE_ATTR

:GET_KANA_ACC
for /F "usebackq eol=# tokens=1* delims=_" %%i in ('%CASE_TOKEN_CDR%') do CALL :GET_CASE_TOKEN %%i %%j
IF "%CASE_TOKEN_CAR%" EQU "SK" GOTO GET_ACC
IF "%CASE_TOKEN_CAR%" EQU "IK" GOTO GET_ACC
IF "%CASE_TOKEN_CAR%" EQU "SA" GOTO GET_CS
IF "%CASE_TOKEN_CAR%" EQU "IA" GOTO GET_CS
GOTO ERR_GET_CASE_ATTR

:GET_ACC
for /F "usebackq eol=# tokens=1* delims=_" %%i in ('%CASE_TOKEN_CDR%') do CALL :GET_CASE_TOKEN %%i %%j
IF "%CASE_TOKEN_CAR%" EQU "SA" GOTO GET_CS
IF "%CASE_TOKEN_CAR%" EQU "IA" GOTO GET_CS
GOTO ERR_GET_CASE_ATTR

:GET_CS
for /F "usebackq eol=# tokens=1* delims=_" %%i in ('%CASE_TOKEN_CDR%') do CALL :GET_CASE_TOKEN %%i %%j
IF "%CASE_TOKEN_CAR%" EQU "SC" SET IS_CS=yes&& GOTO DONE_GET_CASE_ATTR 
IF "%CASE_TOKEN_CAR%" EQU "IC" SET IS_CS=no&& GOTO DONE_GET_CASE_ATTR
GOTO ERR_GET_CASE_ATTR

:SET_SENSITIVE
set IS_CS=yes
GOTO DONE_GET_CASE_ATTR

:ERR_GET_CASE_ATTR
SET T_RC=131
SET T_ERR_MESSAGE=Unable to parse collation string %COLLATION_STRING%
:DONE_GET_CASE_ATTR
GOTO :EOF

:GET_CASE_TOKEN
set CASE_TOKEN_CAR=%1%
set CASE_TOKEN_CDR=%2%
GOTO :EOF

:REVERSE
SET STRING=%1%
SET VAR=%2%
SET BACKWARDS=
SET FCHAR=

:REVERSE_LOOP
IF "%STRING%" EQU "" GOTO :END_REVERSE_LOOP 
SET FCHAR=%STRING:~0,1%
SET STRING=%STRING:~1%
SET BACKWARDS=%FCHAR%%BACKWARDS%
GOTO REVERSE_LOOP

:END_REVERSE_LOOP
SET %VAR%=%BACKWARDS%
GOTO :EOF

:GET_SERVER_NAME
set SERVER_NAME=%1
set INSTANCE_NAME=%2
GOTO :EOF


