REM
REM Name: InstallMDBPatchORA.bat 
REM
REM Description:	Patch an MDB instance on Oracle 
REM 
REM Syntax:
REM
REM 	InstallMDBPatchOra [connect_id] [mdbadmin_pswd] [index tablespace] [patch file] [patch number] [undo]  
REM
REM History:
REM	23-jan-2006 mulwi01
REM	    Created
REM 09-feb-2006 hopst01 add index_tablespace command line argument
REM 20-Mar-2007 STAR issue 14729038, problem MDB 65, replace relative path
REM 1-May-2007 STAR issue 15928642 - case sensitivity with sys
REM 6-June-2007 STAR 16146287, MDB 93 - connect string for Oracle 9 needs quotes
REM 12-Aug-2007 STAR 16208138, MDB 106 - remove quotes added by 16146287
REM 21-Sep-2007 STAR 16382371, MDB 84 - blank in patch path fails
REM 22-Aug-2008 hopst01 STAR 17393114 PATCH MDB PSWORD SPECIAL CHAR, Allow special characters in password by double quoting and escaping the password
REM 09-Sep-2008 rigka01 and hopst01 STAR 17393114, MDB 182 - simplify prev fix 
REM

IF NOT EXIST %LOGFILE% set LOGFILE=install_%1.log
IF (%SQL_CMD%) EQU () set SQL_CMD=sqlplus

set COMMAND_PATH=%~d0%~p0

set MDB_UNDO=%6
set MDB_ACTION=installing
IF (%MDB_UNDO%) EQU (undo) set MDB_ACTION=uninstalling

set MDB_RC_FILE=mdbpatcherr.txt
IF (%MDB_UNDO%) EQU (undo) GOTO GETPSWD
IF EXIST "%MDB_RC_FILE%" GOTO DONE_SKIP_ERROR

:GETPSWD
set MDB_PSWD="%~2"
rem undo "call" stmt
set MDB_PSWD=%MDB_PSWD:^^=^%
rem Escape any reserved shell characters
set MDB_PSWD=%MDB_PSWD:^=^^%
set MDB_PSWD=%MDB_PSWD:<=^<%
set MDB_PSWD=%MDB_PSWD:>=^>%
set MDB_PSWD=%MDB_PSWD:|=^|%
set MDB_PSWD=%MDB_PSWD:&=^&%
set MDB_PSWD=%MDB_PSWD:(=^(%
set MDB_PSWD=%MDB_PSWD:)=^)%
set MDB_PSWD=%MDB_PSWD:"=\"%

set MDB_USE_OS_AUTH=%6%
set MDB_SYS_USER=%7%
set MDB_SYS_PSWD=%8%
set MDB_SYS_PSWD="%~8"
rem undo "call" stmt
set MDB_SYS_PSWD=%MDB_SYS_PSWD:^^=^%
rem Escape any reserved shell characters
set MDB_SYS_PSWD=%MDB_SYS_PSWD:^=^^%
set MDB_SYS_PSWD=%MDB_SYS_PSWD:<=^<%
set MDB_SYS_PSWD=%MDB_SYS_PSWD:>=^>%
set MDB_SYS_PSWD=%MDB_SYS_PSWD:|=^|%
set MDB_SYS_PSWD=%MDB_SYS_PSWD:&=^&%
set MDB_SYS_PSWD=%MDB_SYS_PSWD:(=^(%
set MDB_SYS_PSWD=%MDB_SYS_PSWD:)=^)%
set MDB_SYS_PSWD=%MDB_SYS_PSWD:"=\"%
set MDB_USE_SYS=%9%
set ORA_AS_SYSDBA= as sysdba

REM 15928642 - convert user to lower case

if (%MDB_SYS_USER%) EQU (SYS) set MDB_SYS_USER=sys

REM
REM Check if the patch already exists
REM
echo %date% %time% Checking if the patch already exists 
echo %date% %time% Checking if the patch already exists >> %LOGFILE%
%SQL_CMD% -L "MDBADMIN/%MDB_PSWD%@%1" @"%COMMAND_PATH%\patches\mdb_patch.sql" %5 >>%LOGFILE% 2>&1
set RC=%ERRORLEVEL%
IF (%RC%) EQU (10000) GOTO PATCH_EXISTS

if (%MDB_SYS_USER%) NEQ (sys) GOTO CLEAR_AS_SYSDBA
if (%MDB_USE_OS_AUTH%) NEQ (2) GOTO SETCONNECT
set MDB_USE_OS_AUTH=1

rem if MDB_USE_OS_AUTH = 2 then ORA_AS_SYSDBA needs to be cleared
rem then set to 1 for the check in SETCONNECT to generate to correct
rem connection string

:CLEAR_AS_SYSDBA
set ORA_AS_SYSDBA=

:SETCONNECT

if (%MDB_USE_SYS%) NEQ (sys) GOTO DEFAULT_CONSTR
if (%MDB_USE_OS_AUTH%) EQU (1) GOTO CONSTR_OS_AUTH
set CONNECT_STRING="%MDB_SYS_USER%/%MDB_SYS_PSWD%@%1 %ORA_AS_SYSDBA%"
GOTO DOIT

:CONSTR_OS_AUTH
set CONNECT_STRING=/%ORA_AS_SYSDBA%
GOTO DOIT

:DEFAULT_CONSTR
set CONNECT_STRING="MDBADMIN/%MDB_PSWD%@%1"

:DOIT
echo %date% %time% %MDB_ACTION% patch %5 in database %1  
echo %date% %time% %MDB_ACTION% patch %5 in database %1  >> %LOGFILE%
%SQL_CMD% -L "%CONNECT_STRING%" @%4 %5 %3 >>%LOGFILE% 2>&1
set RC=%ERRORLEVEL%
IF (%RC%) EQU (0) GOTO DONE
echo %date% %time% ***Error %MDB_ACTION% patch %5 in database %1 
echo %date% %time% ***Error %MDB_ACTION% patch %5 in database %1 >> %LOGFILE%
GOTO DONE_ERROR


:PATCH_EXISTS
IF (%MDB_UNDO%) EQU (undo) GOTO DOIT
echo %date% %time% Warning patch %5 already exists in database %1 
echo %date% %time% Warning patch %5 already exists in database %1 >> %LOGFILE%
GOTO DONE

:DONE
exit /B 0

:DONE_ERROR
IF NOT EXIST "%MDB_RC_FILE%" echo %date% %time% ***Error %MDB_ACTION% patch script %5 in database %1 >> "%MDB_RC_FILE%"
exit /B 1

:DONE_SKIP_ERROR
echo %date% %time% Patch %5 was not installed in database %1 because of a previous error >> %LOGFILE%
exit /B 1
