SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 15128417 Portal: Change NCLOB data type in 3 POR tables to LONG     						*/
/*                                                                                      */
/****************************************************************************************/

CREATE TABLE tmp_por_discussion AS SELECT
       objectkey,            
       pathid,               
       childcounter,
       ownerid,        
       subject,             
       content,             
       datemodified,
       depth,        
       changed              
FROM por_discussion;

DROP TABLE por_discussion;

CREATE TABLE por_discussion (
       objectkey            NUMBER(22) NOT NULL,
       pathid               NVARCHAR2(100) NOT NULL,
       childcounter         NUMBER(22) NOT NULL,
       ownerid              NUMBER(22) NOT NULL,
       subject              NVARCHAR2(100) NOT NULL,
       content              LONG NOT NULL,
       datemodified         NUMBER(22) NOT NULL,
       depth                NUMBER(22) NOT NULL,
       changed              NUMBER(22) NOT NULL
);

CREATE INDEX baseidx_por_discussion ON por_discussion
(
       objectkey                      ASC
) tablespace &2 ;

CREATE INDEX discchanged ON por_discussion
(
       changed                        ASC
) tablespace &2 ;

CREATE INDEX discdepth ON por_discussion
(
       depth                          ASC
) tablespace &2 ;

--CREATE INDEX discobkey ON por_discussion
--(
--       objectkey                      ASC
--);

CREATE INDEX discownerid ON por_discussion
(
       ownerid                        ASC
) tablespace &2 ;

CREATE INDEX discpathid ON por_discussion
(
       pathid                         ASC
) tablespace &2 ;



CREATE TABLE tmp_por_preferences AS SELECT
       objectkey,   
       userkey,           
       name,             
       avalue
FROM por_preferences;

DROP TABLE por_preferences;

CREATE TABLE por_preferences (
       objectkey            NUMBER(22) NULL,
       userkey              NUMBER(22) NULL,
       name                 NVARCHAR2(100) NOT NULL,
       avalue               LONG NULL
);

CREATE INDEX baseidx_por_preferences ON por_preferences
(
       objectkey                      ASC
) tablespace &2 ;

CREATE INDEX prefname ON por_preferences
(
       name                           ASC
) tablespace &2 ;

--CREATE INDEX prefobjectkey ON por_preferences
--(
--       objectkey                      ASC
--);

CREATE INDEX prefuserkey ON por_preferences
(
       userkey                        ASC
) tablespace &2 ;


CREATE TABLE tmp_por_templatelookup AS SELECT
       templatekey,
       idx,         
       content
FROM por_templatelookup;

DROP TABLE por_templatelookup;

CREATE TABLE por_templatelookup (
       templatekey          NUMBER(22) NOT NULL,
       idx                  NUMBER(22) NOT NULL,
       content              LONG NOT NULL
);

CREATE INDEX baseidx_por_templatelookup ON por_templatelookup
(
       templatekey                    ASC
) tablespace &2 ;

CREATE INDEX templateindex ON por_templatelookup
(
       idx                            ASC
) tablespace &2 ;

--CREATE INDEX templatekey ON por_templatelookup
--(
--       templatekey                    ASC
--);

/* por_templatelookup */
INSERT INTO POR_TEMPLATELOOKUP SELECT * FROM tmp_por_templatelookup;
DROP TABLE tmp_por_templatelookup;

/* por_discussion */
INSERT INTO POR_DISCUSSION SELECT * FROM tmp_por_discussion;
DROP TABLE tmp_por_discussion;

/* por_preferences */
INSERT INTO POR_PREFERENCES SELECT * FROM tmp_por_preferences;
DROP TABLE tmp_por_preferences;


grant   delete   on por_discussion to portaldba_group
;
grant   update   on por_discussion to portaldba_group
;
grant   select   on por_discussion to portaldba_group
;
grant   insert   on por_discussion to portaldba_group
;
grant   delete   on por_preferences to portaldba_group
;
grant   update   on por_preferences to portaldba_group
;
grant   select   on por_preferences to portaldba_group
;
grant   insert   on por_preferences to portaldba_group
;
grant   delete   on por_templatelookup to portaldba_group
;
grant   update   on por_templatelookup to portaldba_group
;
grant   select   on por_templatelookup to portaldba_group
;
grant   insert   on por_templatelookup to portaldba_group
;

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 15128417, systimestamp, 1, 4, 'Star 15128417 Portal: Change NCLOB data type in 3 POR tables to LONG' );

COMMIT;

EXIT SUCCESS;
