SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 15180170 Autosys: id values							*/
/*                                                                                      */
/****************************************************************************************/

/* 15180170 Autosys: Chk_auto_up fails to show running scheduler */
/* fix TAU MDB Patch Problem with ujo_ha* tables */

/*==============================================================*/
/* Table: ujo_ha_designator                                     */
/*==============================================================*/
drop table ujo_ha_designator cascade constraints
;
create table ujo_ha_designator (
     id                   NUMBER not null,
     name                 varchar2(20)  not null ,
    constraint designator_pk_id primary key (id) using index
)
;

/*==============================================================*/
/* Table: ujo_ha_process                                        */
/*==============================================================*/

drop table ujo_ha_process cascade constraints
;

create table ujo_ha_process (
     pid                  number(11) not null,
     time_stamp           number(11) not null,
     hostname             varchar(255) not null,
     ha_designator_id     number not null,
     ha_status_id         number not null
)
;


/*==============================================================*/
/* Table: ujo_ha_state                                          */
/*==============================================================*/
drop table ujo_ha_state cascade constraints
;

create table ujo_ha_state (
     id                   number not null,
     name                 varchar(20) not null ,    
    constraint ujo_ha_state_PUC primary key (id) using index
)
;

/*==============================================================*/
/* Table: ujo_ha_status                                         */
/*==============================================================*/
drop table ujo_ha_status cascade constraints
;

create table ujo_ha_status (
     id                   number not null,
     name                 varchar(20) not null,     
    constraint ujo_ha_status_PUC primary key (id) using index
)
;


/*==============================================================*/
/* Table: ujo_sys_ha_state                                      */
/*==============================================================*/
drop table ujo_sys_ha_state
;

create table ujo_sys_ha_state (
     id                   number not null,
     ha_state_id          number not null,     
    constraint ujo_sys_ha_state_PUC primary key (id) using index
)
;


alter table ujo_ha_process
   add constraint FK_HA_PROCE_REFERENCE_HA_DESIG foreign key (ha_designator_id)
      references ujo_ha_designator (id)
;


alter table ujo_ha_process
   add constraint FK_HA_PROCE_REFERENCE_HA_STATU foreign key (ha_status_id)
      references ujo_ha_status (id)
;


alter table ujo_sys_ha_state
   add constraint FK_SYS_HA_S_REFERENCE_HA_STATE foreign key (ha_state_id)
      references ujo_ha_state (id)
;


grant select on ujo_ha_designator to ujoadmin
;
grant insert on ujo_ha_designator to ujoadmin
;
grant delete on ujo_ha_designator to ujoadmin
;
grant update on ujo_ha_designator to ujoadmin
;

grant select on ujo_ha_process to ujoadmin
;
grant insert on ujo_ha_process to ujoadmin
;
grant delete on ujo_ha_process to ujoadmin
;
grant update on ujo_ha_process to ujoadmin
;

grant select on ujo_ha_status to ujoadmin
;
grant insert on ujo_ha_status to ujoadmin
;
grant delete on ujo_ha_status to ujoadmin
;
grant update on ujo_ha_status to ujoadmin
;

grant select on ujo_ha_state to ujoadmin
;
grant insert on ujo_ha_state to ujoadmin
;
grant delete on ujo_ha_state to ujoadmin
;
grant update on ujo_ha_state to ujoadmin
;


grant select on ujo_sys_ha_state to ujoadmin
;
grant insert on ujo_sys_ha_state to ujoadmin
;
grant delete on ujo_sys_ha_state to ujoadmin
;
grant update on ujo_sys_ha_state to ujoadmin
;

/* insert into ujo_ha_designator */
insert into ujo_ha_designator (id,name) values (1, 'Primary')
;
insert into ujo_ha_designator (id,name) values (2, 'Shadow')
;
insert into ujo_ha_designator (id,name) values (3, 'Tertiary')
;

/* insert into ujo_ha_state */
insert into ujo_ha_state (id, name) values (1, 'Normal')
;
insert into ujo_ha_state (id, name) values (2, 'Pending')
;
insert into ujo_ha_state (id, name) values (3, 'Failed-over')
;
insert into ujo_ha_state (id, name) values (4, 'No-change')
;

/* insert into ujo_ha_status */
insert into ujo_ha_status (id,name) values (1, 'Active')
;
insert into ujo_ha_status (id,name) values (2, 'Failed')
;
insert into ujo_ha_status (id,name) values (3, 'Dormant')
;

/* insert into ujo_sys_ha_state */
insert into ujo_sys_ha_state (id, ha_state_id)  
  select 1, id FROM ujo_ha_state WHERE name = 'Pending'  
;  




/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 15180170, systimestamp, 1, 4, 'Star 15180170 Autosys: id values' );

COMMIT;

EXIT SUCCESS;
