SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Patch Star 15653570 Autosys: update ujo_det_rep, ujo_jobst, add ujo_jobrow		*/
/*                                                                                      */
/****************************************************************************************/

/* 14910277 Add evt_num to job order sequence */
/* 15653570 - speed up autorep */
CREATE OR REPLACE PACKAGE ujo_det_rep_pkg
AS
    FUNCTION ujo_det_rep(
    i_joid NUMBER ,
    i_run_num NUMBER,
    i_ostatus OUT NUMBER,
    i_oalarm OUT NUMBER,
    i_oevent OUT NUMBER,
    i_oevent_time_gmt OUT NUMBER,
    i_ontry OUT NUMBER,
    i_oque_status OUT NUMBER,
    i_omonth OUT NUMBER,
    i_oday OUT NUMBER,
    i_oyear OUT NUMBER,
    i_ohours OUT NUMBER,
    i_ominutes OUT NUMBER,
    i_oseconds OUT NUMBER,
    i_otext OUT VARCHAR2,
    i_omachine OUT VARCHAR2,
    i_oevt_num OUT NUMBER,
    o_over_num OUT NUMBER,
    done_fetch OUT NUMBER,
    found OUT NUMBER) RETURN INTEGER;
END;
/
CREATE OR REPLACE PACKAGE BODY ujo_det_rep_pkg AS

    CURSOR ujo_get_det_rep(i_joid IN NUMBER, i_run_num IN NUMBER) IS
        SELECT status,
            alarm,
            event,
            event_time_gmt,
            ntry,
            que_status,
            TO_NUMBER(TO_CHAR(que_status_stamp, 'MM')),
            TO_NUMBER(TO_CHAR(que_status_stamp, 'DD')),
            TO_NUMBER(TO_CHAR(que_status_stamp, 'YYYY')),
            TO_NUMBER(TO_CHAR(que_status_stamp, 'HH24')),
            TO_NUMBER(TO_CHAR(que_status_stamp, 'MI')),
            TO_NUMBER(TO_CHAR(que_status_stamp, 'SS')),
            text,
            machine,
            evt_num
        FROM ujo_eventvu
        WHERE joid = i_joid
        AND run_num = i_run_num
        UNION
        SELECT status,
            alarm,
            event,
            event_time_gmt,
            ntry,
            que_status,
            TO_NUMBER(TO_CHAR(que_status_stamp, 'MM')),
            TO_NUMBER(TO_CHAR(que_status_stamp, 'DD')),
            TO_NUMBER(TO_CHAR(que_status_stamp, 'YYYY')),
            TO_NUMBER(TO_CHAR(que_status_stamp, 'HH24')),
            TO_NUMBER(TO_CHAR(que_status_stamp, 'MI')),
            TO_NUMBER(TO_CHAR(que_status_stamp, 'SS')),
            text,
            machine,
            evt_num
        FROM ujo_proc_eventvu
        WHERE joid = i_joid
        AND run_num = i_run_num
        ORDER BY event_time_gmt, evt_num;

    FUNCTION ujo_det_rep(
        i_joid NUMBER ,
        i_run_num NUMBER,
        i_ostatus OUT NUMBER,
        i_oalarm OUT NUMBER,
        i_oevent OUT NUMBER,
        i_oevent_time_gmt OUT NUMBER,
        i_ontry OUT NUMBER,
        i_oque_status OUT NUMBER,
        i_omonth OUT NUMBER,
        i_oday OUT NUMBER,
        i_oyear OUT NUMBER,
        i_ohours OUT NUMBER,
        i_ominutes OUT NUMBER,
        i_oseconds OUT NUMBER,
        i_otext OUT VARCHAR2,
        i_omachine OUT VARCHAR2,
        i_oevt_num OUT NUMBER,
        o_over_num OUT NUMBER,
        done_fetch OUT NUMBER,
        found OUT NUMBER)
    RETURN INTEGER AS
        temp_done_fetch INTEGER;
        temp_found INTEGER;
        temp_evt_num INTEGER;
    BEGIN
        IF NOT ujo_get_det_rep%ISOPEN THEN
            OPEN ujo_get_det_rep(i_joid, i_run_num);
        END IF;

        temp_done_fetch := 1;
        temp_found := 0;
        FETCH ujo_get_det_rep
        INTO i_ostatus,
            i_oalarm,
            i_oevent,
            i_oevent_time_gmt,
            i_ontry,
            i_oque_status,
            i_omonth,
            i_oday,
            i_oyear,
            i_ohours,
            i_ominutes,
            i_oseconds,
            i_otext,
            i_omachine,
            i_oevt_num;
        IF ujo_get_det_rep%NOTFOUND THEN
            CLOSE ujo_get_det_rep;
            temp_done_fetch := 0;
        ELSE
            temp_found := temp_found + 1;
            temp_done_fetch := 1;
        END IF;
                SELECT max(over_num) into o_over_num FROM ujo_overjob WHERE joid=i_joid AND run_num=i_run_num;

        done_fetch := temp_done_fetch;
        found := temp_found;
        RETURN 4;
    END;
END;
/
grant execute on ujo_det_rep_pkg to ujoadmin;


/* 15653570 - speed up autorep */
drop view ujo_jobst;

CREATE VIEW  ujo_jobst
AS
SELECT j.*, status, status_time, run_num, ntry, appl_ntry, last_start,
	last_end,next_start,exit_code,run_machine, que_name,
	run_priority, next_priority, pid, jc_pid,time_ok,
	last_heartbeat,j2.timezone,j2.as_applic,j2.as_group
FROM	ujo_job j, ujo_job_status s, ujo_job2 j2
WHERE j.joid = s.joid and j.joid=j2.joid;

grant select on ujo_jobst to ujoadmin;


CREATE VIEW ujo_jobrow AS
    SELECT  j.joid, j.job_name,j.job_type,j.owner,j.permission,
        j.box_joid,j.machine,j.n_retrys,
        j.date_conditions,j.days_of_week,j.run_calendar,j.exclude_calendar,
        j.start_times,j.start_mins,j.run_window,
        j.command,
        j.description, j.term_run_time,
        j.box_terminator,
        j.job_terminator,j.std_in_file,j.std_out_file,j.std_err_file,
        j.watch_file,j.watch_file_min_size,j.watch_interval,
        j.min_run_alarm, j.max_run_alarm, j.alarm_if_fail,
        j.chk_files,j.free_procs,j.profile,j.heartbeat_interval,
        j.auto_hold,
        j.job_load,j.priority, j.auto_delete, j.numero,
        j.max_exit_success, j.box_success, j.box_failure,
        status,status_time,last_start,last_end,next_start,run_window_end,
        exit_code,run_machine,que_name,jc_pid,pid,
        run_num, ntry, appl_ntry, last_heartbeat,
        run_priority, next_priority, evt_num, over_num,
        b.job_name box_name,j2.command2, j2.external_app, j2.timezone,
        j2.as_applic,j2.as_group,j.send_notification, j.service_desk
    FROM ujo_job_status s, ujo_job j, ujo_job b, ujo_job2 j2
    WHERE s.joid = j.joid
    AND j.joid = j2.joid
    AND j.box_joid = b.joid (+);

grant select on ujo_jobrow to ujoadmin;


/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 15653570, systimestamp, 1, 4, 'Star 15653570 (MODIFIED v4) Autosys: ujo_get_jobrow' );

COMMIT;

EXIT SUCCESS;
