rem @Echo off

REM Name: setupmdb_post.bat 
REM
REM Description: 
REM    internal post-process script for mdb on SQLServer
REM 
REM Syntax:
REM
REM    setupmdb_post
REM
REM History:
REM    18-jul-2006  mulwi01  created 
REM    21-jul-2006  mulwi01  make a signature error non-fatal
REM    30-mar-2006  hopst01  added support for windows or sql authentication
REM    21-sep-2007  hopst01  display version information from mdb_version, suppress display of patches
REM    29-nov-2007  johri05  b1628 Consistency of logged messages time stamps
REM                      Add :GET_DT--Get Date/Time func to fmt logged timestamp
REM                      to match Java Utilities and LinuxUnix install scripts.
REM    14-dec-2007  johri05  b1628 Consistency of logged messages time stamps
REM                      Copy fixed :GET_DT func from setupmdb.bat
REM                      Fixed :GET_DT--"Get Date/Time" func, to always use 24-hr fmt
REM                      Also fixed to use %TMPDIR% for temporary (writable) directory.
REM    18-jul-2008  hopst01  Star 17294367 DBPASSWORD WITH "," FAILED. Treat DBPASSWORD like 
REM                          MDB_ADMIN_PSWD.  Use temp variable when comparing it to an 
REM                          empty string.
REM    05-aug-2008  hopst01  b1917 - STAR 17340801 Use TCP connection host,port unless 
REM                          port is 0 this replaces dbhost in the connection string 
REM    08-aug-2008  johri05  b1882-17149528-MDBTOOLS DATE TIME ERROR LOG
REM                          Fix to use only minimal short format to prefix logged messages.
REM                          Long format is to be used once in the install log header.
REM                             long fmt:  yyyy-MMM-dd,HH:mm:ss-zzzz -ex:2008-jul-04,15:30:00-0400
REM                             short fmt:       MM-dd,HH:mm:ss      -ex:      07-04,15:30:00
REM                          Del :GET_DT function
REM                          Chg calls to :GET_DT label to be calls to mdbFuncs with GET_DT argument
REM    11-aug-2008  hopst01  b1882-17149528-MDBTOOLS DATE TIME ERROR LOG. Target Directory needs to 
REM                          be quoted. Don't pipe calls to mdbFuncs to nul as it makes debug impossible.
REM    27-aug-2008  hopst01  b1949 - Don't inherit sigfile location
REM

setlocal

set MDB_RC=2


rem
rem Get TMPDIR for general use.
rem (use tgt dir for post-script)
rem
set TMPDIR=%MDB_TARGET_DIR%


rem
rem check if SQLServer is available
rem
sqlcmd -? > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
    set SQL_CMD=sqlcmd
    GOTO OSQL_FOUND
)
osql -? > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
    set SQL_CMD=osql
    GOTO OSQL_FOUND
)

set MDB_RC=10
set ERR_MESSAGE=cannot find osql or sqlcmd. Check that SQLServer has been installed and in the PATH
GOTO DONE_EXIT
:OSQL_FOUND

rem
rem determine if using windows or sql server authentication
rem
set AUTH=-E
set ECHOED_AUTH=-E
SET T_DBPASSWORD=x%DBPASSWORD%x
SET T_DBPASSWORD="%T_DBPASSWORD:"=%"
IF (%DBUSER%) NEQ () IF (%T_DBPASSWORD%) NEQ ("xx") GOTO SQL_AUTH
GOTO AUTH_SET
:SQL_AUTH
set AUTH=-U %DBUSER% -P %DBPASSWORD_DQ%
set ECHOED_AUTH=-U %DBUSER% -P ***
:AUTH_SET



rem
rem cleanup? 
rem
IF NOT "%1"=="cleanup" GOTO NO_CLEAN
call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% Removing failed mdb... >>%LOGFILE%
%SQL_CMD% -S %DBMS_INSTANCE% -d master %AUTH% -e -b -Q "drop database [%DBNAME%]" >>%LOGFILE% 2>&1
set ERR_MESSAGE=Removed the %DBNAME% database
set MDB_RC=0
GOTO DONE_EXIT
:NO_CLEAN



set SIGFILE="%MDB_TARGET_DIR%\%DBNAME%_signature.txt"


REM
REM create the signature... 
REM

call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% Creating the %DBNAME% signature in %SIGFILE% 

echo MdbName=%DBNAME%                                               >  %SIGFILE%
echo DbmsType=SQLServer                                             >> %SIGFILE%




REM
REM add the current date... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'SignatureDate='+cast(getdate() as varchar)" > mdbsig.txt
findstr /B /L /C:"SignatureDate=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_SIGDATE
type mdbsig.txt 
del mdbsig.txt > nul
set MDB_RC=11
set ERR_MESSAGE=CreateMDBSignature: error on mdb.SignatureDate
GOTO DONE_EXIT

:FOUND_SIGDATE
findstr /B /L /C:"SignatureDate=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul



REM
REM add the majorversion... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'MdbMajorVersion='+cast(mdbMajorVersion as varchar(5)) from mdb" > mdbsig.txt
findstr /B /L /C:"MdbMajorVersion=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_MAJOR
type mdbsig.txt 
del mdbsig.txt > nul
rem
rem allow missing mdb table
rem
rem set MDB_RC=12
set MDB_RC=0
set ERR_MESSAGE=CreateMDBSignature: error on mdb.mdbMajorVersion
GOTO DONE_EXIT

:FOUND_MAJOR
findstr /B /L /C:"MdbMajorVersion=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul



REM
REM add the minorversion... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'MdbMinorVersion='+cast(mdbMinorVersion as varchar(5)) from mdb" > mdbsig.txt
findstr /B /L /C:"MdbMinorVersion=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_MINOR
type mdbsig.txt 
del mdbsig.txt > nul
set MDB_RC=13
set ERR_MESSAGE=CreateMDBSignature: error on mdb.mdbMinorVersion
GOTO DONE_EXIT

:FOUND_MINOR
findstr /B /L /C:"MdbMinorVersion=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul



REM
REM add the build... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'BuildNumber='+cast(buildNumber as varchar(5)) from mdb" > mdbsig.txt
findstr /B /L /C:"BuildNumber=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_BUILD
type mdbsig.txt 
del mdbsig.txt > nul
set MDB_RC=14
set ERR_MESSAGE=CreateMDBSignature: error on mdb.buildNumber
GOTO DONE_EXIT

:FOUND_BUILD
findstr /B /L /C:"BuildNumber=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul




REM
REM add the release date... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'ReleaseDate='+cast(releaseDate as varchar) from mdb" > mdbsig.txt
findstr /B /L /C:"ReleaseDate=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_RDATE
type mdbsig.txt 
del mdbsig.txt > nul
set MDB_RC=15
set ERR_MESSAGE=CreateMDBSignature: error on mdb.ReleaseDate
GOTO DONE_EXIT

:FOUND_RDATE
findstr /B /L /C:"ReleaseDate=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul




REM
REM add the install date... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'InstallDate='+cast(installDate as varchar) from mdb" > mdbsig.txt
findstr /B /L /C:"InstallDate=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_IDATE
type mdbsig.txt 
del mdbsig.txt > nul
rem allow null date
GOTO END_IDATE

:FOUND_IDATE
findstr /B /L /C:"InstallDate=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul
:END_IDATE



REM
REM add the patches... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'Patch='+cast(patchnumber as varchar(10))+',' +char(34)+cast(installdate as varchar)+ char(34) + ',' + char(34) +cast(description as varchar)+ char(34) from mdb_patch" > mdbsig.txt
findstr /B /L /C:"Patch=" mdbsig.txt > nul 2>&1 
if %ERRORLEVEL% EQU 0 GOTO FOUND_PATCH
REM type mdbsig.txt 
del mdbsig.txt > nul
rem allow no patches
GOTO CURRENT_VERSION_INFO 

:FOUND_PATCH
findstr /B /L /C:"Patch=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul


:CURRENT_VERSION_INFO
REM
REM add the current majorversion... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'CurrentMdbMajorVersion='+cast(mdbMajorVersion as varchar(5)) from mdb_version" > mdbsig.txt
findstr /B /L /C:"CurrentMdbMajorVersion=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_CURRENT_MAJOR
type mdbsig.txt 
del mdbsig.txt > nul
rem
rem allow missing mdb table
rem
rem set MDB_RC=12
set MDB_RC=0
set ERR_MESSAGE=CreateMDBSignature: error on mdb_version.mdbMajorVersion
GOTO DONE_EXIT

:FOUND_CURRENT_MAJOR
findstr /B /L /C:"CurrentMdbMajorVersion=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul



REM
REM add the current minorversion... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'CurrentMdbMinorVersion='+cast(mdbMinorVersion as varchar(5)) from mdb_version" > mdbsig.txt
findstr /B /L /C:"CurrentMdbMinorVersion=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_CURRENT_MINOR
type mdbsig.txt 
del mdbsig.txt > nul
set MDB_RC=13
set ERR_MESSAGE=CreateMDBSignature: error on mdb_version.mdbMinorVersion
GOTO DONE_EXIT

:FOUND_CURRENT_MINOR
findstr /B /L /C:"CurrentMdbMinorVersion=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul



REM
REM add the current build... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'CurrentBuildNumber='+cast(buildNumber as varchar(5)) from mdb_version" > mdbsig.txt
findstr /B /L /C:"CurrentBuildNumber=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_CURRENT_BUILD
type mdbsig.txt 
del mdbsig.txt > nul
set MDB_RC=14
set ERR_MESSAGE=CreateMDBSignature: error on mdb_version.buildNumber
GOTO DONE_EXIT

:FOUND_CURRENT_BUILD
findstr /B /L /C:"CurrentBuildNumber=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul


REM
REM add the current release date... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'CurrentReleaseDate='+cast(releaseDate as varchar) from mdb_version" > mdbsig.txt
findstr /B /L /C:"CurrentReleaseDate=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_CURRENT_RDATE
type mdbsig.txt 
del mdbsig.txt > nul
set MDB_RC=15
set ERR_MESSAGE=CreateMDBSignature: error on mdb_version.ReleaseDate
GOTO DONE_EXIT

:FOUND_CURRENT_RDATE
findstr /B /L /C:"CurrentReleaseDate=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul




REM
REM add the current install date... 
REM

IF EXIST mdbsig.txt del mdbsig.txt
%SQL_CMD% -S %DBMS_INSTANCE% -d %DBNAME% -h-1 -s. %AUTH% -b -Q "select 'CurrentInstallDate='+cast(installDate as varchar) from mdb_version" > mdbsig.txt
findstr /B /L /C:"CurrentInstallDate=" mdbsig.txt 
if %ERRORLEVEL% EQU 0 GOTO FOUND_CURRENT_IDATE
type mdbsig.txt 
del mdbsig.txt > nul
rem allow null date
GOTO END_CURRENT_IDATE

:FOUND_CURRENT_IDATE
findstr /B /L /C:"CurrentInstallDate=" mdbsig.txt >> %SIGFILE%
del mdbsig.txt > nul
:END_CURRENT_IDATE


:DONE

set ERR_MESSAGE=Created the %DBNAME% signature
set MDB_RC=0


:DONE_EXIT

call "%MDB_SOURCE_DIR%\mdbFuncs"  GET_DT  "%MDB_TARGET_DIR%"
echo %DT% %ERR_MESSAGE%
echo %DT% %ERR_MESSAGE% >> %LOGFILE% 2>&1

echo %DT% Setupmdb_post exit /B return code=%MDB_RC% >> %LOGFILE% 2>&1

EXIT /B %MDB_RC%

