SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE; 

SET AUTOCOMMIT OFF;

/****************************************************************************************/
/*                                                                                      */
/* Star 15000408 UAPM: Implement new UAPM functionality for customer CSC      					*/
/*                                                                                      */
/****************************************************************************************/

/* SQL for 11.CSC changes*/

/*****************************************************************************/
/* NOTE!!!!!!!!  Run this before running 11.CSC Oracl mdb data update.sql */
/*****************************************************************************/

/* create the arg_hierarchy_def table */

CREATE TABLE arg_hierarchy_def (
        hierarchy_id NUMBER not null,
        hierarchy_name NVARCHAR2(255) not null,
        hierarchy_type NVARCHAR2(100) not null,
        ext_table_name NVARCHAR2(32),
        last_update_user NVARCHAR2(64),
        last_update_date NUMBER,
        version_number NUMBER default 0 null);

/* define the primary key */

CREATE INDEX arg_hierarchy_def_idx_01 ON arg_hierarchy_def
(
       hierarchy_id                  ASC
) tablespace &2 ;

/* create the arg_hierarchy_values table */

CREATE TABLE arg_hierarchy_values (
        hierarchy_id NUMBER not null,
        hierarchy_value_id NUMBER not null,
        hierarchy_value NVARCHAR2(255) not null,
        parent_id NVARCHAR2(32),
        inactive NUMBER default 0 not null,
        last_update_user NVARCHAR2(64),
        last_update_date NUMBER,
        version_number NUMBER default 0 null);

/* define the primary key */

CREATE INDEX arg_hierarchy_values ON arg_hierarchy_values
(
       hierarchy_value_id                  ASC
) tablespace &2 ;

CREATE INDEX arg_hierarchy_values_idx_02 on arg_hierarchy_values
(
       parent_id    ASC
) tablespace &2 ;

/***********************************************************************************/

/* alter the arg_extension_rule_def table */

ALTER TABLE arg_extension_rule_def ADD hierarchy_id NUMBER null;

/***********************************************************************************/

/* alter the arg_field_def table */

ALTER TABLE arg_field_def ADD ishierarchy NUMBER null;

/***********************************************************************************/

/* alter the arg_attribute_def table */

ALTER TABLE arg_attribute_def ADD api_property_name NVARCHAR2(100) null;

ALTER TABLE arg_attribute_def ADD api_object_name NVARCHAR2(100) null;

ALTER TABLE arg_attribute_def ADD api_updatable NUMBER null;

ALTER TABLE arg_attribute_def ADD api_searchable NUMBER null;

ALTER TABLE arg_attribute_def ADD hierarchy NUMBER null;

/***********************************************************************************/   

/* alter the arg_roledef table */

ALTER TABLE arg_roledef ADD inactive NUMBER default 0 NULL;

/***********************************************************************************/

/* add organization_uuid fields */

/* alter the arg_legaldoc table */

ALTER TABLE arg_legaldoc ADD organization_uuid RAW(16) null;

ALTER TABLE arg_legaldoc ADD owner_uuid RAW(16) null;

ALTER TABLE arg_legaldoc ADD manager_uuid RAW(16) null;

ALTER TABLE arg_legaldoc ADD cost_approver_uuid RAW(16) null;

/* alter the ca_location table */

ALTER TABLE ca_location ADD organization_uuid RAW(16) null;

/* alter the ca_resource_cost_center table */

ALTER TABLE ca_resource_cost_center ADD organization_uuid RAW(16) null;

CREATE INDEX ca_resource_cost_center_idx_02 ON ca_resource_cost_center
(
       organization_uuid                           ASC
) tablespace &2 ;

/* alter the ca_resource_department table */

ALTER TABLE ca_resource_department ADD organization_uuid RAW(16) null;

CREATE INDEX ca_resource_department_idx_02 ON ca_resource_department
(
       organization_uuid                           ASC
) tablespace &2 ;

/* alter the ca_job_title table */

ALTER TABLE ca_job_title ADD organization_uuid RAW(16) null;

CREATE INDEX ca_job_title_idx_02 ON ca_job_title
(
       organization_uuid                           ASC
) tablespace &2 ;

/* alter the ca_job_function table */

ALTER TABLE ca_job_function ADD organization_uuid RAW(16) null;

CREATE INDEX ca_job_function_idx_02 ON ca_job_function
(
       organization_uuid                           ASC
) tablespace &2 ;

/* alter the arg_drpdnlst table */

ALTER TABLE arg_drpdnlst ADD organization_uuid RAW(16) null;

CREATE INDEX arg_drpdnlst_idx_04 ON arg_drpdnlst
(
       organization_uuid                           ASC
) tablespace &2 ;

/***********************************************************************************/

/* create the arg_link_notification_attachmt table */

CREATE TABLE arg_link_notification_attachmt (
        object_uuid RAW(16) not null ,
        amid NUMBER not null ,
        nyerid NUMBER not null ,
        nyid NUMBER not null ,
        last_update_date NUMBER null ,
        version_number NUMBER default 0 null);

/* define the primary key */

CREATE UNIQUE INDEX arg_link_notif_attachmt_idx_01 on arg_link_notification_attachmt (
       object_uuid ASC,
       amid ASC,
       nyerid ASC,
       nyid ASC)
tablespace &2 ;
/***********************************************************************************/

/* create the ca_agent table */              

CREATE TABLE ca_agent (
	last_run_date NUMBER NULL,
	object_uuid RAW(16) NOT NULL,
	agent_version NVARCHAR2(32) NULL,
	description NVARCHAR2(255) NULL,
	prev_manager NVARCHAR2(255) NULL,
	server_uuid RAW(16) NULL,
	agent_area NVARCHAR2(64) NULL,
	agent_file_id NVARCHAR2(36) NULL,
	agent_type NUMBER NULL,
	creation_user NVARCHAR2(255) NULL,
	creation_date NUMBER NULL,
	last_update_user NVARCHAR2(255) NULL,
	last_update_date NUMBER NULL,
	version_number NUMBER default 0 NULL,
	class_id NUMBER NULL,
	domain_id NUMBER NULL,
	unit_id NUMBER NULL,
	agent_name NVARCHAR2(192) NULL,
	boot_server_uuid RAW(16) NULL,
	registration_type NUMBER NULL,
	auto_server_version NUMBER default 0 NULL,
	auto_rep_version DATE NULL,
	agent_ref_count NUMBER NULL,
	agent_lock NUMBER NULL,
	derived_status_am NUMBER default 0 NULL,
	derived_status_sd NUMBER default 0 NULL,
	derived_status_rc NUMBER default 0 NULL,
	derived_status_babld NUMBER default 0 NULL,
	ip_address NVARCHAR2(64) NULL,
	proc_os_id NUMBER NULL,
	user_def1 NVARCHAR2(255) NULL,
	user_def2 NVARCHAR2(255) NULL,
	user_def3 NVARCHAR2(255) NULL,
	user_def4 NVARCHAR2(255) NULL 
);

ALTER TABLE ca_agent 
    ADD CONSTRAINT XPKca_agent PRIMARY KEY 
	(object_uuid); 

CREATE INDEX ca_agent_idx0 ON ca_agent
(
       agent_type ASC
) tablespace &2 ;

CREATE INDEX ca_agent_idx1 ON ca_agent
(
       unit_id ASC,
       domain_id ASC
) tablespace &2 ;
                        

/* create the ca_server table */

CREATE TABLE ca_server (
	domain_uuid RAW(16) NOT NULL,
	host_name NVARCHAR2(255) NULL,
	label NVARCHAR2(255) NULL,
	share_unc_path NVARCHAR2(127) NULL,
	server_con_type NUMBER NOT NULL,
	validation_interval_number NUMBER NULL,
	validation_interval_status NUMBER NULL,
	validation_interval_time NUMBER NULL,
	validation_interval_date NUMBER NULL,
	description NVARCHAR2(255) NULL,
	creation_user NVARCHAR2(255) NULL,
	creation_date NUMBER NULL,
	last_update_user NVARCHAR2(255) NULL,
	server_uuid RAW(16) NOT NULL,
	version_number NUMBER default 0 NULL,
	last_update_date NUMBER NULL,
	dis_hw_uuid RAW(16) NULL,
	old_flg NUMBER NULL,
	auto_rep_version DATE NULL 
);

ALTER TABLE ca_server 
    ADD CONSTRAINT XPKca_server PRIMARY KEY 
	(server_uuid); 
	
ALTER TABLE ca_agent 
        ADD CONSTRAINT ca_ag_r0000086400000000
              FOREIGN KEY (server_uuid)
              		REFERENCES ca_server (server_uuid);
	
/* add new fields to the ca_owned_resource table */


ALTER TABLE ca_owned_resource ADD alternate_host_name nvarchar2(255) null
;
ALTER TABLE ca_owned_resource ADD discovery_last_run_date number null
;
ALTER TABLE ca_owned_resource ADD previous_resource_tag nvarchar2(64) null
;
ALTER TABLE ca_owned_resource ADD processor_count number null
;
ALTER TABLE ca_owned_resource ADD processor_speed float null
;
ALTER TABLE ca_owned_resource ADD processor_speed_unit number null
;
ALTER TABLE ca_owned_resource ADD processor_type nvarchar2(50) null
;
ALTER TABLE ca_owned_resource ADD reconciliation_date number null
;
ALTER TABLE ca_owned_resource ADD total_disk_space float null
;
ALTER TABLE ca_owned_resource ADD total_disk_space_unit number null
;
ALTER TABLE ca_owned_resource ADD total_memory float null
;
ALTER TABLE ca_owned_resource ADD total_memory_unit number null
;
ALTER TABLE ca_owned_resource ADD billing_contact_uuid RAW(16) null
;
ALTER TABLE ca_owned_resource ADD support_contact1_uuid RAW(16) null
;
ALTER TABLE ca_owned_resource ADD support_contact2_uuid RAW(16) null
;
ALTER TABLE ca_owned_resource ADD support_contact3_uuid RAW(16) null
;
ALTER TABLE ca_owned_resource ADD disaster_recovery_contact_uuid RAW(16) null
;
ALTER TABLE ca_owned_resource ADD backup_services_contact_uuid RAW(16) null
;
ALTER TABLE ca_owned_resource ADD network_contact_uuid RAW(16) null
;

/* add new fields to the arg_reconcile_task table */


ALTER TABLE arg_reconcile_task ADD watch_disk_space_switch number null
;
ALTER TABLE arg_reconcile_task ADD watch_memory_switch number null
;
ALTER TABLE arg_reconcile_task ADD watch_processor_count_switch number null
;
ALTER TABLE arg_reconcile_task ADD watch_processor_speed_switch number null
;
ALTER TABLE arg_reconcile_task ADD watch_processor_type_switch number null
;
ALTER TABLE arg_reconcile_task ADD watch_last_run_date_switch number null
;


/* add new fields to the arg_reconcile_data table */


ALTER TABLE arg_reconcile_data ADD discovery_last_run_date number null
;
ALTER TABLE arg_reconcile_data ADD discovery_processor_count number null
;
ALTER TABLE arg_reconcile_data ADD discovery_processor_speed float null
;
ALTER TABLE arg_reconcile_data ADD discovery_processor_speed_unit number null
;
ALTER TABLE arg_reconcile_data ADD discovery_processor_type nvarchar2(50) null
;
ALTER TABLE arg_reconcile_data ADD discovery_total_disk_space float null
;
ALTER TABLE arg_reconcile_data ADD discovery_total_disk_space_unt number null
;
ALTER TABLE arg_reconcile_data ADD discovery_total_memory float null
;
ALTER TABLE arg_reconcile_data ADD discovery_total_memory_unit number null
;

/* Note: The GRANT statements are absent.  There is legacy code in UAPM Database Utility to handle this already */

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 15000408, systimestamp, 1, 4, 'Star 15000408 UAPM: Implement new UAPM functionality for customer CSC' );

COMMIT;

EXIT SUCCESS;
