SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 15881095 Autosys: procedure ujo_chk_cond					*/
/*                                                                                      */
/****************************************************************************************/


CREATE OR REPLACE PACKAGE BODY ujo_chk_cond_pkg AS

    CURSOR ujo_get_data_mode1 IS
        SELECT job_name Job, cond_job_name Missing_Condition_Job
        FROM ujo_job j join ujo_job_cond c on j.joid = c.joid
        WHERE NOT EXISTS (SELECT 1 FROM ujo_job WHERE job_name = c.cond_job_name)
       		AND cond_job_name is NOT NULL
       	 	AND type != 'g'
       	 	AND cond_job_AUTOSERV is NULL   -- No X-instance checking
			AND c.over_num = -1;
		
	CURSOR ujo_get_data_othermodes IS
        SELECT job_name Job, cond_job_name Missing_Condition_Job
        FROM ujo_job j join ujo_job_cond c on j.joid = c.joid
			join ujo_job_status s on j.joid = s.joid
        WHERE NOT EXISTS (SELECT 1 FROM ujo_job WHERE job_name = c.cond_job_name)
        	AND cond_job_name is NOT NULL
        	AND type != 'g'
        	AND cond_job_AUTOSERV is NULL   -- No X-instance checking
			AND c.over_num = s.over_num;
		
	CURSOR ujo_get_data_onice_mode1 IS
        SELECT j.job_name Job, cond_job_name Condition_Job_ON_ICE
        FROM ujo_job j join ujo_job_cond c on j.joid = c.joid
        	join ujo_job_status s on j.joid = s.joid
			join ujo_job j2 on s.joid = j2.joid
        WHERE cond_job_name = j2.job_name
        	AND s.status = 7     -- 7=ON_ICE
        	AND cond_job_name is NOT NULL
        	AND cond_job_AUTOSERV is NULL
        	AND c.over_num = -1;
        
    CURSOR ujo_get_data_onice_othermodes IS
        SELECT j.job_name Job, cond_job_name Condition_Job_ON_ICE
        FROM ujo_job j join ujo_job_cond c on j.joid = c.joid
        	join ujo_job_status s on j.joid = s.joid
			join ujo_job j2 on s.joid = j2.joid
        WHERE cond_job_name = j2.job_name
        	AND s.status = 7     -- 7=ON_ICE
        	AND cond_job_name is NOT NULL
        	AND cond_job_AUTOSERV is NULL
        	AND c.over_num = s.over_num;    

    CURSOR ujo_get_data2_mode1(i_job_name IN VARCHAR2) IS
        SELECT cond_job_name Missing_Condition_Job
        FROM ujo_job j join ujo_job_cond c on j.joid = c.joid
        WHERE NOT EXISTS (SELECT 1 FROM ujo_job WHERE job_name = c.cond_job_name)
		   	AND j.job_name = i_job_name
        	AND cond_job_name is NOT NULL
        	AND type != 'g'
        	AND cond_job_AUTOSERV is NULL
        	AND c.over_num = -1;
        
    CURSOR ujo_get_data2_othermodes(i_job_name IN VARCHAR2) IS
        SELECT cond_job_name Missing_Condition_Job
         FROM ujo_job j join ujo_job_cond c on j.joid = c.joid
			join ujo_job_status s on j.joid = s.joid
        WHERE NOT EXISTS (SELECT 1 FROM ujo_job WHERE job_name = c.cond_job_name)
		   	AND j.job_name = i_job_name
        	AND cond_job_name is NOT NULL
        	AND type != 'g'
        	AND cond_job_AUTOSERV is NULL
        	AND c.over_num = s.over_num;
  
    FUNCTION ujo_chk_cond(i_job_name VARCHAR2  DEFAULT 'ALL',
		i_mode NUMBER,
        i_ojob_name OUT VARCHAR2,
        i_ocond_job_name OUT VARCHAR2,
        done_fetch OUT NUMBER,
        found OUT NUMBER)
    RETURN INTEGER AS
        temp_done_fetch INTEGER;
        temp_found INTEGER;

    BEGIN
        IF i_job_name = 'ALL' THEN                 --    ***** ALL *****
        IF (i_mode = 1) THEN
        
            IF NOT ujo_get_data_mode1%ISOPEN THEN
                OPEN ujo_get_data_mode1;
                DBMS_OUTPUT.PUT_LINE('Jobs which specify a Job in a Condition for which there is NOT a Job defined.') ;
            END IF;

            temp_done_fetch := 1;
            temp_found := 0;

            FETCH ujo_get_data_mode1
                INTO i_ojob_name, i_ocond_job_name;

            IF ujo_get_data_mode1%NOTFOUND THEN
                CLOSE ujo_get_data_mode1;
                temp_done_fetch := 0;
            ELSE
                temp_found := temp_found + 1;
            END IF;

            done_fetch := temp_done_fetch;
            found := temp_found;

            RETURN -999;
        ELSE
            IF NOT ujo_get_data_othermodes%ISOPEN THEN
                OPEN ujo_get_data_othermodes;
                DBMS_OUTPUT.PUT_LINE('Jobs which specify a Job in a Condition for which there is NOT a Job defined.') ;
            END IF;

            temp_done_fetch := 1;
            temp_found := 0;

            FETCH ujo_get_data_othermodes
                INTO i_ojob_name, i_ocond_job_name;

            IF ujo_get_data_othermodes%NOTFOUND THEN
                CLOSE ujo_get_data_othermodes;
                temp_done_fetch := 0;
            ELSE
                temp_found := temp_found + 1;
            END IF;

            done_fetch := temp_done_fetch;
            found := temp_found;
            RETURN -999;			

        END IF;
        END IF;

        IF i_job_name = 'ON_ICE' THEN                 --    ***** ON_ICE *****
        IF (i_mode = 1) THEN
            IF NOT ujo_get_data_onice_mode1%ISOPEN THEN
                OPEN ujo_get_data_onice_mode1;
                DBMS_OUTPUT.PUT_LINE('Jobs which depend (starting conditions) on a Job which is currently ON_ICE.');
            END IF;

            temp_done_fetch := 1;
            temp_found := 0;

            FETCH ujo_get_data_onice_mode1
                INTO i_ojob_name, i_ocond_job_name;

            IF ujo_get_data_onice_mode1%NOTFOUND THEN
                CLOSE ujo_get_data_onice_mode1;
                temp_done_fetch := 0;
            ELSE
                temp_found := temp_found + 1;
            END IF;

            done_fetch := temp_done_fetch;
            found := temp_found;

            RETURN -999;
        ELSE
            IF NOT ujo_get_data_onice_othermodes%ISOPEN THEN
                OPEN ujo_get_data_onice_othermodes;
                DBMS_OUTPUT.PUT_LINE('Jobs which depend (starting conditions) on a Job which is currently ON_ICE.');
            END IF;

            temp_done_fetch := 1;
            temp_found := 0;

            FETCH ujo_get_data_onice_othermodes
                INTO i_ojob_name, i_ocond_job_name;

            IF ujo_get_data_onice_othermodes%NOTFOUND THEN
                CLOSE ujo_get_data_onice_othermodes;
                temp_done_fetch := 0;
            ELSE
                temp_found := temp_found + 1;
            END IF;

            done_fetch := temp_done_fetch;
            found := temp_found;
            RETURN -999;        

        END IF;
        END IF;
             
             
        IF (i_mode = 1) THEN                                               -- ***** by job *****
			IF NOT ujo_get_data2_mode1%ISOPEN THEN
				OPEN ujo_get_data2_mode1(i_job_name);
			END IF;

			temp_done_fetch := 1;
			temp_found := 0;

			FETCH ujo_get_data2_mode1
				INTO i_ocond_job_name;

			IF ujo_get_data2_mode1%NOTFOUND THEN
				CLOSE ujo_get_data2_mode1;
				temp_done_fetch := 0;
			ELSE
				temp_found := temp_found + 1;
			END IF;

			done_fetch := temp_done_fetch;
			found := temp_found;
			RETURN -999;
        ELSE
			IF NOT ujo_get_data2_othermodes%ISOPEN THEN
				OPEN ujo_get_data2_othermodes(i_job_name);
			END IF;

			temp_done_fetch := 1;
			temp_found := 0;

			FETCH ujo_get_data2_othermodes
				INTO i_ocond_job_name;

			IF ujo_get_data2_othermodes%NOTFOUND THEN
				CLOSE ujo_get_data2_othermodes;
				temp_done_fetch := 0;
			ELSE
				temp_found := temp_found + 1;
			END IF;

			done_fetch := temp_done_fetch;
			found := temp_found;
			RETURN -999;
		END IF;
    END;
END;
/

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 15881095, systimestamp, 1, 4, 'Star 15881095 Autosys: procedure ujo_chk_cond' );

COMMIT;

EXIT SUCCESS;
