SET ECHO ON;
WHENEVER OSERROR EXIT FAILURE;
WHENEVER SQLERROR EXIT SQL.SQLCODE;

SET AUTOCOMMIT OFF;


/****************************************************************************************/
/*                                                                                      */
/* Star 16255155 DSM: add ca_agent_ip_list and ip6Tohex					*/
/*                                                                                      */
/****************************************************************************************/
SET ESCAPE ON;

/**
 * Copyright (c) , 2007
 *
 * SQl script to upgrade the DSM MDB schema to support IPv6
 *
 */


/**
 * function to convert IP address of colon notation to a hex string
 *
 * CAVEATS:
 *	no full support of Zero-compression
 *	***************************************************************************
 */
-- ipaddr_str can describe 16 raw=32 half bytes including 15 colons =47 chars
CREATE OR REPLACE function ip6ColTohex(ipaddr_str in char )
RETURN raw is erg_raw raw(16);

	erg_str 		varchar2(64); -- ipaddr_str without colons. max length: 16 * 2
	erg_str1 		varchar2(64); -- ipaddr_str without colons. max length: 16 * 2
	pos 			number;
	found 			number;
	len			number;
	len_part 		number;
	partcount		number;
	found2colons	number;
	ipaddr_part 	varchar2(64); -- max 4 chars: ABCF
	ipaddr_part2 	varchar2(64); -- max 4 chars: ABCF
BEGIN

	--dbms_output.put_line('ip6ColTohex started');

	if ipaddr_str is NULL
	then
		-- Error
		return NULL;
	end if;


	len:=length(ipaddr_str);
	pos:=1;
	erg_str:='';
	erg_str1:='';
	partcount:=0;
	found2colons:=0;

	-- check for correctness: no . allowed, mixed mode not supported.
	found:=instr(ipaddr_str, '.');
	if found > 0 
	then
		-- Error
		return NULL;
	end if;


	-- check for correctness: at least one : expected mixed mode not supported.
	found:=instr(ipaddr_str, ':');
	if found = 0 
	then
		-- Error
		return NULL;
	end if;



	while  (pos < len + 1 )
	loop

		found := instr( ipaddr_str, ':',  pos );
		-- 0: end of string found, fetch the rest
		if found = 0
		then
			found:=len + 1;
		end if;

		ipaddr_part:=rtrim(ltrim(substr(ipaddr_str,pos,found-pos)));
		len_part:=length(ipaddr_part);

		if len_part != 0
		then
			ipaddr_part2:= substr('0000',1,4-len_part) || ipaddr_part;
			erg_str:=erg_str || ipaddr_part2;
			partcount:=partcount + 1;

		else
			-- support of short format ::
			-- :: is replaced by 0000... (see below)
			-- :: can only occur ones, otherwise NULL returned
			erg_str1:=erg_str;
			erg_str:='';
			found2colons:=found2colons+1;
		end if;

		dbms_output.put_line(erg_str1 || '....' || erg_str);

		-- pos to next part of ipaddr_str
		pos:=found + 1;

	end loop;


	if found2colons > 1
	then
		return NULL;
	end if;
	if found2colons = 1
	then
		erg_str:=erg_str1 || rpad('0000', 4*(8-partcount), '0') || erg_str;
	end if;
	if length(erg_str) = 32
	then
		return hextoraw(erg_str);
	end if;

	return NULL;

	EXCEPTION
	when others
		then
		return NULL;
END;

/
grant execute on ip6ColTohex to ca_itrm_group
;
grant execute on ip6ColTohex to ca_itrm_group_ams
;

/* ip2hex_int converts ipv4 addresses to binary.
	for example: 1.2.3.4 -> '01020304'

	In case of an error NULL is returned.
*/
create or replace FUNCTION ip2hex_int(ipaddr_str in char )  
RETURN raw is erg raw(4);
	ipaddr_hex raw(4);
	ipbyte number;
	ipbyte_hex raw(1);
	temp varchar(64);
	ch char(1);
	last_ch char(1);
	error number;
BEGIN 

	--dbms_output.put_line('ip2hex started');

	error:=0;
	if ipaddr_str is NULL
	then
		dbms_output.put_line('NULL found');
		return NULL;
	end if;
	ipbyte := 0;
	temp := ltrim(ipaddr_str);
	if temp = ''
	then
		dbms_output.put_line('empty string found');
		return NULL;
	end if;
	if substr(temp,1,1) = '.'
	then
		dbms_output.put_line('starting . found');
		return NULL;
	end if;
	if length(temp) is NULL
	then
		dbms_output.put_line('NULL found');
		return NULL;
	end if;
	last_ch:='';
	ipaddr_hex:=NULL;

	--dbms_output.put_line('temp:' || temp || ':' || length(temp) || ':' );
	while  length(temp)>0
	loop
		ch := substr( temp, 1, 1 );
		-- dbms_output.put_line(ch || '  ' || rawtohex(ipaddr_hex) || '  ' || to_char(ipbyte));
		if ch = '.'
		then
			if last_ch = '.'
			then
				return NULL;
			end if;
			ipbyte_hex:=utl_raw.substr(utl_raw.cast_from_binary_integer(ipbyte),4,1);
			if utl_raw.substr(utl_raw.cast_from_binary_integer(ipbyte),1,3) != hextoraw('000000')
			then
				error:=1;
				exit; -- end loop
			end if;
			ipaddr_hex:=ipaddr_hex || ipbyte_hex;
			ipbyte := 0;
		else 
			ipbyte := ipbyte*10 + ch;
		end if;

		temp:=ltrim(substr(temp,2));
	end loop;

	if utl_raw.substr(utl_raw.cast_from_binary_integer(ipbyte),1,3) != hextoraw('000000')
	then
		error:=1;
	end if;
	if error=1
	then
		return NULL;
	end if;
	ipbyte_hex:=utl_raw.substr(utl_raw.cast_from_binary_integer(ipbyte),4,1);
	ipaddr_hex:=ipaddr_hex || ipbyte_hex;
	return ipaddr_hex;

	EXCEPTION
	when others
		then
		return NULL;
END;
/
grant execute on ip2hex_int to ca_itrm_group
;


/* ip2hex converts ipv4 addresses to binary.
	for example: 1.2.3.4 -> '01020304'

	In case of an error '00000000' is returned, to make
	it compatible to ip2hex for MsSQL
*/
create or replace FUNCTION ip2hex(ipaddr_str in char )  
RETURN raw is erg raw(4);
	ipaddr_hex raw(4);
BEGIN 

		ipaddr_hex:=ip2hex_int(ipaddr_str);
		if ipaddr_hex is NULL
			then
			return hextoraw('00000000');
		else
			return ipaddr_hex;
		end if;

END;
/

grant execute on ip2hex to ca_itrm_group
;
grant execute on ip2hex to ca_itrm_group_ams
;


/**
 * function to convert
 *		IPv4 address - dotted notation OR
 *		IPv6 address - colon hexadecimal OR
 * 		to 16 raw hex string
 *
 *	***************************************************************************
 */
CREATE OR REPLACE FUNCTION ip6Tohex(ipaddr_str in char )
RETURN raw is erg_raw raw(16);
	ipaddr_hex 	raw(16);

BEGIN

	--dbms_output.put_line('ip6Tohex started');

	if ipaddr_str = NULL
	then
		ipaddr_hex := NULL;
		return ipaddr_hex;

	end if;


	if  instr(ipaddr_str, ':') >0 
	then
		-- must be an IPv6 address
		-- colon hexadecimal address
		ipaddr_hex := ip6ColTohex(ipaddr_str);
		return ipaddr_hex;
	end if;


	-- must be an IPv4 address

	if  instr(ipaddr_str, '.') >0 
	then
		if ip2hex_int(ipaddr_str) is null
		then
			return NULL;
		else
			ipaddr_hex := hextoraw('000000000000000000000000')||ip2hex_int(ipaddr_str);
			return ipaddr_hex;
		end if;

	end if;

	return NULL;


END;
/
grant execute on ip6Tohex to ca_itrm_group
;
grant execute on ip6Tohex to ca_itrm_group_ams
;

/**
 * ***************************************************************************
 *  new table to  hold multiple IP addresses fro an single agent
 * ***************************************************************************
 */
CREATE TABLE ca_agent_ip_list
(
	object_uuid  raw(16)  NOT NULL ,
	ip_address  nvarchar2(64)  NOT NULL ,
	auto_rep_version   DATE  NULL
)
;

ALTER TABLE ca_agent_ip_list
	ADD  PRIMARY KEY   (object_uuid, ip_address)
;

grant select, insert, update, delete on ca_agent_ip_list to ca_itrm_group
;
grant select on ca_agent_ip_list to ca_itrm_group_ams
;


/*
 ****************************************************************************
 * procedure called by a trigger on MDBADMIN.delete on ca_agent
 *****************************************************************************
*/
-- /
CREATE OR REPLACE procedure MDBADMIN.p_integrity_d_agent(
	old_object_uuid in raw 	/* old object uuid */
	)
as

begin
  delete from ca_agent_component where object_uuid = old_object_uuid;
  delete from ca_agent_ip_list where object_uuid = old_object_uuid;
end;
/
grant execute on p_integrity_d_agent to ca_itrm_group
;

/****************************************************************************************/
/*                                                                                      */
/* Register patch                                                                       */
/*                                                                                      */
/****************************************************************************************/
INSERT INTO mdb_patch ( patchnumber, installdate,  mdbmajorversion, mdbminorversion, description)
 VALUES ( 16255155, systimestamp, 1, 4, 'Star 16255155 DSM: add ca_agent_ip_list and ip6Tohex' );

COMMIT;

EXIT SUCCESS;
