rem @Echo off
REM
REM Name: precheck_extension.bat
REM
REM Description:
REM   internal additional precheck script for mdb on Oracle
REM
REM Syntax:
REM
REM   setupmdb_pre
REM
REM History:
REM   25-oct-2007  hopst01  created
REM   20-nov-2007  hopst01  Remove quotes from around values pre-check values
REM   21-dec-2007  hopst01  16587331 - Fix syntax error in ERR_EXIT
REM   14-jul-2008  hopst01  b1766 - PRECHECK FAILURE (Star 17044308).  
REM                         Fix syntax error in ERR_EXIT
REM    05-dec-2008  hopst01  17704532 - R11.2 NM SQL DB UPDATE FAILS. For loops that use 
REM                          a command to populate the for loop set should be replaced. 
REM

set RC=14
set MESSAGE_TEXT=

set ORA_CONNECT_ID=%DBNAME%
set ORA_SYS_PSWD=%DBPASSWORD%
set ORA_SYS_USER=sys
IF (%DBUSER%) NEQ () set ORA_SYS_USER=%DBUSER%


rem
rem check required arguments
rem

IF (%ORA_CONNECT_ID%) NEQ () GOTO REQ_ARG1
set MESSAGE_TEXT=Missing required argument: DBNAME (Oracle connection id)
GOTO ERR_EXIT

:REQ_ARG1
IF (%ORA_SYS_PSWD%) NEQ () GOTO EXC_ARG
set MESSAGE_TEXT=Missing required argument: DBPASSWORD (Oracle SYS password)
GOTO ERR_EXIT

:EXC_ARG

rem
rem check if Oracle is available
rem
sqlplus -V > nul 2>&1
IF %ERRORLEVEL% NEQ 9009 (
    set SQL_CMD=sqlplus
    GOTO OSQL_FOUND
)
set RC=10
set MESSAGE_TEXT=Cannot find sqlplus. Check that Oracle has been installed and in the PATH
GOTO ERR_EXIT
:OSQL_FOUND



REM 
REM check oracle connectivity
REM
echo quit | %SQL_CMD% -L "%ORA_SYS_USER%/%ORA_SYS_PSWD%@%ORA_CONNECT_ID%%ORA_AS_SYSDBA%" > nul 2>&1
if (%ERRORLEVEL%) EQU (0) GOTO CONN_OK

echo quit | %SQL_CMD% -L "%ORA_SYS_USER%/%ORA_SYS_PSWD%@%ORA_CONNECT_ID%%ORA_AS_SYSDBA%" >> %LOGFILE% 2>&1
set RC=104
set MESSAGE_TEXT=Oracle connectivity error, unable to connect as user %ORA_SYS_USER% 
GOTO ERR_EXIT

:CONN_OK

REM
REM CHECK FOR THE NUMBER OF LOGINS CONNECTED TO THE DATABASE
REM

:COUNT_CONNECTED
SET RC=0
SET LOGIN_COUNT=
SET LOGIN_LIST=
SET TEMP_LOGIN_NAME=

IF EXIST temp_output.txt del temp_output.txt
%SQL_CMD% -L "%ORA_SYS_USER%/%ORA_SYS_PSWD%@%ORA_CONNECT_ID%%ORA_AS_SYSDBA%" @.\DDL\list_users.sql > nul 2>&1
set RC=%ERRORLEVEL%
IF %RC% EQU 0 GOTO PARSE_POPULATE_RESULT
IF EXIST temp.txt del temp.txt
IF EXIST temp_output.txt del temp_output.txt
set MESSAGE_TEXT=Unable to determine the users connected to the database.
GOTO ERR_EXIT

REM
REM Parse the query results in the temp file and compile list of connect users
REM
:PARSE_POPULATE_RESULT
set LOGIN_COUNT=0
for /F "tokens=1,2 delims==" %%i IN (temp_output.txt) DO IF ("%%j") NEQ ("") CALL :SET_LOGIN_LIST %%j

REM cleanup
IF EXIST temp.txt del temp.txt
IF EXIST temp_output.txt del temp_output.txt

IF "%LOGIN_COUNT%" EQU "" GOTO LIST_ERR
IF "%LOGIN_LIST%"  EQU "" GOTO LIST_ERR
GOTO PRINT_LIST_RESULT
:LIST_ERR
set RC=15
set MESSAGE_TEXT=Unable to determine the users connected to the database.
GOTO ERR_EXIT

:PRINT_LIST_RESULT
set MESSAGE_TEXT=%LOGIN_COUNT%
SET MESSAGE_NAME=NUMBER_CONNECTIONS
CALL :PRINT_MSG

set MESSAGE_TEXT=%LOGIN_LIST%
set MESSAGE_NAME=CONNECTION_LIST
CALL :PRINT_MSG

:DONE_LOGIN_COUNT
GOTO DONE_EXIT

REM
REM FUNCTIONS
REM

rem
rem Prints out message in format message_name="message_text"
rem
:PRINT_MSG
IF (%PRECHECK_MSGFILE%) EQU ()  goto PRECHK_STDOUT
echo %MESSAGE_NAME%=%MESSAGE_TEXT%       >> %PRECHECK_MSGFILE%
GOTO :EOF
:PRECHK_STDOUT
echo %MESSAGE_NAME%=%MESSAGE_TEXT%
GOTO :EOF

rem
rem Builds up list of connected user and updates total count 
rem
:SET_LOGIN_LIST
set TEMP_LOGIN_NAME=%1%
IF "%LOGIN_LIST%" EQU "" GOTO BLANK_LOGIN_NAME
set LOGIN_LIST=%TEMP_LOGIN_NAME%,%LOGIN_LIST%
GOTO UPDATE_COUNT

:BLANK_LOGIN_NAME
set LOGIN_LIST=%TEMP_LOGIN_NAME%
GOTO UPDATE_COUNT

:UPDATE_COUNT
SET /A LOGIN_COUNT=1 + %LOGIN_COUNT%
GOTO :EOF

REM
REM Exit script
REM

:ERR_EXIT
SET MDB_RC=%RC%
IF "%MESSAGE_TEXT%" EQU "" GOTO DONE_EXIT
SET ERR_MESSAGE=%MESSAGE_TEXT%

:DONE_EXIT
EXIT /B %RC%

